@@ -215,9 +215,9 @@ void AutoSubprojectView::initActions()
 	addApplicationAction->setWhatsThis(i18n("<qt><b>Add application</b><p>Creates an application .desktop file.</qt>"));
 	addApplicationAction->plug( m_button4 );
 
-	QToolTip::add( m_button5, tr2i18n( "Add Build"));
+	QToolTip::add( m_button5, tr2i18n( "Build"));
 	buildSubprojectAction = new AutoToolsAction( i18n( "Build" ), "launch", 0, this,
-	                                     SLOT( slotBuildSubproject() ), actions, "add build subproject" );
+	                                     SLOT( slotBuildSubproject() ), actions, "build subproject" );
 	buildSubprojectAction->setWhatsThis(i18n("<qt><b>Build</b><p>Runs <b>make</b> from the directory of "
 	                                         "the selected subproject.<br> Environment variables and "
 	                                         "make arguments can be specified in the project settings "
@@ -763,13 +763,31 @@ void AutoSubprojectView::parseSUBDIRS( SubprojectItem *item,
 	{
 		QStringList dirs;
 		QFile subdirsfile( item->path + "/subdirs" );
-		if ( subdirsfile.open( IO_ReadOnly ) )
-		{
-			QTextStream subdirsstream( &subdirsfile );
-			while ( !subdirsstream.atEnd() )
-				dirs.append( subdirsstream.readLine() );
-			subdirsfile.close();
-		}
+        if( subdirsfile.exists() )
+        {
+		    if ( subdirsfile.open( IO_ReadOnly ) )
+		    {
+			    QTextStream subdirsstream( &subdirsfile );
+			    while ( !subdirsstream.atEnd() )
+				    dirs.append( subdirsstream.readLine() );
+			    subdirsfile.close();
+		    }
+        } else
+        {
+            QDir d( item->path );
+            QStringList l = d.entryList( QDir::Dirs );
+            for( QStringList::const_iterator it = l.begin(); it != l.end(); ++it )
+            {
+                if( (*it) != "CVS" && (*it) != "admin" && (*it) != ".svn" && (*it) != "." && (*it) != ".." )
+                {
+                    QDir subdir = d;
+                    subdir.cd( *it, false );
+                    if( subdir.exists( "Makefile.am" ) )
+                        dirs.append( *it );
+                }
+            }
+
+        }
 		subdirs.replace( QRegExp( "\\$\\(TOPSUBDIRS\\)" ), dirs.join( " " ) );
 	}
 
