@@ -18,18 +18,22 @@
 #include <qdir.h>
 #include <qpair.h>
 #include <qmakedriver.h>
+#include <qregexp.h>
+#include <qtimer.h>
 
 #include <kdirwatch.h>
 
 #include "pathutil.h"
 #include "trollprojectpart.h"
+#include "qmakedefaultopts.h"
+#include "pathutil.h"
 
 const QStringList Scope::KnownVariables = QStringList() << "QT" << "CONFIG" << "TEMPLATE" << "SUBDIRS" << "VERSION" << "LIBS" << "target.path" << "INSTALLS" << "MAKEFILE" << "TARGETDEPS" << "INCLUDEPATH" << "TARGET" << "DESTDIR" << "DEFINES" << "QMAKE_CXXFLAGS_DEBUG" << "QMAKE_CXXFLAGS_RELEASE" << "OBJECTS_DIR" << "UI_DIR" << "MOC_DIR" << "IDL_COMPILER" << "IDL_OPTIONS" << "RCC_DIR" << "IDLS" << "RESOURCES" << "IMAGES" << "LEXSOURCES" << "DISTFILES" << "YACCSOURCES" << "TRANSLATIONS" << "HEADERS" << "SOURCES" << "INTERFACES" << "FORMS" ;
 
 const QStringList Scope::KnownConfigValues = QStringList() << "debug" << "release" << "debug_and_release" << "warn_on" << "warn_off" << "staticlib" << "dll" << "plugin" << "designer" << "create_pkgconf" << "create_libtool" << "qt" << "console" << "windows" << "x11" << "thread" << "exceptions" << "stl" << "rtti" << "opengl" << "thread" << "ordered" << "precompile_header" << "qtestlib" << "uitools" << "dbus" << "assistant" << "build_all";
 
 Scope::Scope( const QString &filename, TrollProjectPart* part )
-    : m_root( 0 ), m_incast( 0 ), m_parent( 0 ), m_num(0), m_isEnabled( true ), m_part(part)
+    : m_root( 0 ), m_incast( 0 ), m_parent( 0 ), m_num(0), m_isEnabled( true ), m_part(part), m_defaultopts(0)
 {
     if ( !loadFromFile( filename ) )
     {
@@ -43,8 +47,12 @@ Scope::Scope( const QString &filename, TrollProjectPart* part )
             m_root = 0;
         }
     }
+    loadDefaultOpts();
     if( m_root )
+    {
         m_part->dirWatch()->addFile(filename);
+    }
+    init();
 }
 
 Scope::~Scope()
@@ -59,23 +67,34 @@ Scope::~Scope()
 
     m_customVariables.clear();
 
-    if ( m_root && m_root->isProject() )
+    if ( m_root && m_root->isProject() && !m_incast )
+    {
         delete m_root;
-    m_root = 0;
+        m_root = 0;
+        delete m_defaultopts;
+        m_defaultopts = 0;
+    }
+
 }
 
-Scope::Scope( unsigned int num, Scope* parent, QMake::ProjectAST* scope, TrollProjectPart* part )
-    : m_root( scope ), m_incast( 0 ), m_parent( parent ), m_num(num), m_isEnabled( true ), m_part(part)
+// Simple/Function Scopes
+Scope::Scope( unsigned int num, Scope* parent, QMake::ProjectAST* scope,
+              QMakeDefaultOpts* defaultopts, TrollProjectPart* part )
+    : m_root( scope ), m_incast( 0 ), m_parent( parent ), m_num(num), m_isEnabled( true ),
+        m_part(part), m_defaultopts(defaultopts)
 {
     init();
 }
 
-Scope::Scope( unsigned int num, Scope* parent, const QString& filename, TrollProjectPart* part, bool isEnabled )
-: m_root( 0 ), m_incast( 0 ), m_parent( parent ), m_num(num), m_isEnabled( isEnabled ), m_part(part)
+//Subdirs
+Scope::Scope( unsigned int num, Scope* parent, const QString& filename,
+              TrollProjectPart* part, bool isEnabled )
+    : m_root( 0 ), m_incast( 0 ), m_parent( parent ), m_num(num), m_isEnabled( isEnabled ),
+    m_part(part), m_defaultopts(0)
 {
     if ( !loadFromFile( filename ) )
     {
-        if( !QFileInfo( filename ).exists() )
+        if( !QFileInfo( filename ).exists() && QFileInfo( QFileInfo( filename ).dirPath( true ) ).exists() )
         {
             m_root = new QMake::ProjectAST();
             m_root->setFileName( filename );
@@ -83,29 +102,48 @@ Scope::Scope( unsigned int num, Scope* parent, const QString& filename, TrollPro
         {
             delete m_root;
             m_root = 0;
+            m_isEnabled = false;
         }
     }
+    loadDefaultOpts();
     if( m_root )
         m_part->dirWatch()->addFile(filename);
+    init();
 }
 
-Scope::Scope( unsigned int num, Scope* parent, QMake::IncludeAST* incast, const QString& path, const QString& incfile, TrollProjectPart* part )
-        : m_root( 0 ), m_incast( incast ), m_parent( parent ), m_num(num), m_isEnabled( true ), m_part(part)
+//Include Scope
+Scope::Scope( unsigned int num, Scope* parent, QMake::IncludeAST* incast, const QString& path,
+              const QString& incfile, QMakeDefaultOpts* defaultopts, TrollProjectPart* part )
+    : m_root( 0 ), m_incast( incast ), m_parent( parent ), m_num(num), m_isEnabled( true ),
+    m_part(part), m_defaultopts(defaultopts)
 {
-    if ( !loadFromFile( path + QString( QChar( QDir::separator() ) ) + incfile ) )
+    QString absfilename;
+    QString tmp;
+    if( incfile.contains(")" ) )
+        tmp = incfile.mid(0, incfile.find(")") );
+    else
+        tmp = incfile;
+    if( QFileInfo(tmp).isRelative() )
     {
-        if( !QFileInfo( path + QString( QChar( QDir::separator() ) ) + incfile ).exists() )
+        absfilename = path + QString( QChar( QDir::separator() ) ) + tmp;
+    }else
+        absfilename = tmp;
+    if ( !loadFromFile( absfilename ) )
+    {
+        if( !QFileInfo( absfilename ).exists() && QFileInfo( QFileInfo( absfilename ).dirPath( true ) ).exists() )
         {
             m_root = new QMake::ProjectAST();
-            m_root->setFileName( QString( path + QString( QChar( QDir::separator() ) ) + incfile ) );
+            m_root->setFileName( absfilename );
         }else
         {
             delete m_root;
             m_root = 0;
+            m_isEnabled = false;
         }
     }
     if( m_root )
         m_part->dirWatch()->addFile( m_root->fileName() );
+    init();
 }
 
 bool Scope::loadFromFile( const QString& filename )
@@ -116,7 +154,7 @@ bool Scope::loadFromFile( const QString& filename )
         m_root = 0;
         return false;
     }
-    init();
+//     init();
     return true;
 }
 
@@ -258,52 +296,56 @@ QStringList Scope::variableValuesForOp( const QString& variable , const QString&
     return result;
 }
 
-QStringList Scope::variableValues( const QString& variable ) const
+QStringList Scope::variableValues( const QString& variable, bool checkIncParent )
 {
     QStringList result;
 
     if ( !m_root )
         return result;
 
-    if ( variable == "QT" )
+    if( m_varCache.contains( variable ) && ( checkIncParent || scopeType() != Scope::IncludeScope ) )
     {
-        result << "gui" << "core";
-    }
-    else if ( variable == "CONFIG" && m_part->isQt4Project() )
-    {
-        result << "warn_on" << "qt" << "stl";
-    }
-    else if ( variable == "CONFIG" && !m_part->isQt4Project() )
-    {
-        result << "qt" << "warn_on" << "thread";
+        return m_varCache[variable];
     }
 
-    result = calcValuesFromStatements( variable, result );
+    calcValuesFromStatements( variable, result, checkIncParent );
     result.remove( "\\\n" );
     result.remove( "\n" );
     result = Scope::removeWhiteSpace(result);
+    if( scopeType() != Scope::IncludeScope || checkIncParent )
+    {
+        m_varCache[ variable ] = result;
+    }
     return result;
 }
 
-QStringList Scope::calcValuesFromStatements( const QString& variable, QStringList result, QMake::AST* stopHere ) const
+void Scope::calcValuesFromStatements( const QString& variable, QStringList& result, bool checkIncParent, QMake::AST* stopHere ) const
 {
     if( !m_root )
-        return result;
+        return;
+
+    /* For variables that we don't know and which are not QT/CONFIG find the default value */
+    if( m_defaultopts
+        && m_defaultopts->variables().findIndex(variable) != -1
+        && ( variable == "TEMPLATE" || variable == "QT" || KnownVariables.findIndex(variable) == -1 || variable == "CONFIG" ) )
+    {
+        result = m_defaultopts->variableValues(variable);
+    }
 
     if ( scopeType() == FunctionScope || scopeType() == SimpleScope )
     {
-        result = m_parent->calcValuesFromStatements( variable, result , this->m_root );
+        m_parent->calcValuesFromStatements( variable, result , this->m_root );
+    }
+    else if ( scopeType() == IncludeScope && checkIncParent )
+    {
+        m_parent->calcValuesFromStatements( variable, result , this->m_incast );
     }
-//     else if ( scopeType() == IncludeScope )
-//     {
-//         result = m_parent->calcValuesFromStatements( variable, result , this->m_incast );
-//     }
 
     QValueList<QMake::AST*>::const_iterator it;
     for ( it = m_root->m_children.begin(); it != m_root->m_children.end(); ++it )
     {
         if ( stopHere && *it == stopHere )
-            return result;
+            return ;
         QMake::AST* ast = *it;
         if ( ast->nodeType() == QMake::AST::AssignmentAST )
         {
@@ -318,7 +360,7 @@ QStringList Scope::calcValuesFromStatements( const QString& variable, QStringLis
                 {
                     for ( QStringList::const_iterator sit = assign->values.begin(); sit != assign->values.end() ; ++sit )
                     {
-                        if ( !result.contains( *sit ) )
+                        if ( result.findIndex( *sit ) == -1 )
                             result.append( *sit );
                     }
                 }
@@ -326,7 +368,7 @@ QStringList Scope::calcValuesFromStatements( const QString& variable, QStringLis
                 {
                     for ( QStringList::const_iterator sit = assign->values.begin(); sit != assign->values.end() ; ++sit )
                     {
-                        if ( result.contains( *sit ) )
+                        if ( result.findIndex( *sit ) != -1 )
                             result.remove( *sit );
                     }
                 }
@@ -336,7 +378,7 @@ QStringList Scope::calcValuesFromStatements( const QString& variable, QStringLis
 
     result.remove( "\\\n" );
     result.remove( "\n" );
-    return result;
+    return ;
 }
 
 Scope::ScopeType Scope::scopeType() const
@@ -402,7 +444,7 @@ Scope* Scope::createFunctionScope( const QString& funcName, const QString& args
     ast->addChildAST( new QMake::NewLineAST() );
     m_root->addChildAST( ast );
     m_root->addChildAST( new QMake::NewLineAST() );
-    Scope* funcScope = new Scope( getNextScopeNum(), this, ast, m_part );
+    Scope* funcScope = new Scope( getNextScopeNum(), this, ast, m_defaultopts, m_part );
     if( funcScope->scopeType() != Scope::InvalidScope )
     {
         m_scopes.insert( getNextScopeNum(), funcScope );
@@ -425,7 +467,7 @@ Scope* Scope::createSimpleScope( const QString& scopename )
     m_root->addChildAST( new QMake::NewLineAST() );
     if ( m_part->isQt4Project() )
         addToPlusOp( "CONFIG", QStringList( scopename ) );
-    Scope* simpleScope = new Scope( getNextScopeNum(), this, ast, m_part );
+    Scope* simpleScope = new Scope( getNextScopeNum(), this, ast, m_defaultopts, m_part );
 
     if( simpleScope->scopeType() != Scope::InvalidScope )
     {
@@ -457,7 +499,7 @@ Scope* Scope::createIncludeScope( const QString& includeFile, bool negate )
     QMake::IncludeAST* ast = new QMake::IncludeAST();
     ast->setDepth( m_root->depth() );
     ast->projectName = includeFile;
-    Scope* incScope = new Scope( funcScope->getNextScopeNum(), funcScope, ast, projectDir(), ast->projectName, m_part );
+    Scope* incScope = new Scope( funcScope->getNextScopeNum(), funcScope, ast, projectDir(), resolveVariables( ast->projectName ), m_defaultopts, m_part );
     if ( incScope->scopeType() != InvalidScope )
     {
         funcScope->m_root->addChildAST( ast );
@@ -478,38 +520,44 @@ Scope* Scope::createSubProject( const QString& projname )
     if( !m_root )
         return 0;
 
-    if( variableValuesForOp( "SUBDIRS", "-=").contains( projname ) )
+    if( variableValuesForOp( "SUBDIRS", "-=").findIndex( projname ) != -1 )
         removeFromMinusOp( "SUBDIRS", projname );
 
+    QString realprojname = resolveVariables(projname);
+
+    if( variableValuesForOp( "SUBDIRS", "-=").findIndex( realprojname ) != -1 )
+        removeFromMinusOp( "SUBDIRS", realprojname );
+
     QDir curdir( projectDir() );
 
-    if ( variableValues("TEMPLATE").contains( "subdirs" ) )
+    if ( variableValues("TEMPLATE").findIndex( "subdirs" ) != -1 )
     {
         QString filename;
-        if( !projname.endsWith(".pro") )
+        if( !realprojname.endsWith(".pro") )
         {
-            if ( !curdir.exists( projname ) )
-                if ( !curdir.mkdir( projname ) )
+            if ( !curdir.exists( realprojname ) )
+                if ( !curdir.mkdir( realprojname ) )
                     return 0;
-            curdir.cd( projname );
+            curdir.cd( realprojname );
             QStringList entries = curdir.entryList("*.pro", QDir::Files);
 
-            if ( !entries.isEmpty() && !entries.contains( curdir.dirName()+".pro" ) )
+            if ( !entries.isEmpty() && entries.findIndex( curdir.dirName()+".pro" ) == -1 )
                 filename = curdir.absPath() + QString(QChar(QDir::separator()))+entries.first();
             else
                 filename = curdir.absPath() + QString(QChar(QDir::separator()))+curdir.dirName()+".pro";
         }else
-            filename = curdir.absPath() + QString(QChar(QDir::separator())) + projname;
+            filename = curdir.absPath() + QString(QChar(QDir::separator())) + realprojname;
 
         kdDebug( 9024 ) << "Creating subproject with filename:" << filename << endl;
 
         Scope* s = new Scope( getNextScopeNum(), this, filename, m_part );
+        s->loadDefaultOpts();
         if ( s->scopeType() != InvalidScope )
         {
             if( s->variableValues("TEMPLATE").isEmpty() )
                 s->setEqualOp("TEMPLATE", QStringList("app"));
             s->saveToFile();
-            addToPlusOp( "SUBDIRS", QStringList( projname ) );
+            addToPlusOp( "SUBDIRS", QStringList( realprojname ) );
             m_scopes.insert( getNextScopeNum(), s );
             return s;
         } else
@@ -590,11 +638,12 @@ bool Scope::deleteSubProject( unsigned int num, bool deleteSubdir )
     if ( it != m_root->m_children.end() )
     {
         QMake::AssignmentAST * tempast = static_cast<QMake::AssignmentAST*>( *it );
-        if ( tempast->values.contains( "subdirs" ) )
+        if ( tempast->values.findIndex( "subdirs" ) != -1 )
         {
             Scope* project = m_scopes[ num ];
             if( !project )
                 return false;
+            QString projdir = project->scopeName();
             if ( deleteSubdir )
             {
                 QDir projdir = QDir( projectDir() );
@@ -621,7 +670,9 @@ bool Scope::deleteSubProject( unsigned int num, bool deleteSubdir )
             if ( foundit != m_root->m_children.end() )
             {
                 QMake::AssignmentAST * ast = static_cast<QMake::AssignmentAST*>( *foundit );
-                updateValues( ast->values, QStringList( project->scopeName() ), true, ast->indent );
+                updateValues( ast->values, QStringList( projdir ), true, ast->indent );
+                if( m_varCache.contains( "SUBDIRS" ) )
+                    m_varCache.erase( "SUBDIRS" );
             }else
                 return false;
             m_scopes.remove( num );
@@ -639,7 +690,7 @@ void Scope::updateValues( QStringList& origValues, const QStringList& newValues,
 
     for ( QStringList::const_iterator it = newValues.begin(); it != newValues.end() ; ++it )
     {
-        if ( !origValues.contains( *it ) && !remove )
+        if ( origValues.findIndex( *it ) == -1 && !remove )
         {
             while ( !origValues.isEmpty() && origValues.last() == "\n" )
                 origValues.pop_back();
@@ -655,12 +706,15 @@ void Scope::updateValues( QStringList& origValues, const QStringList& newValues,
                     origValues.append( indent );
             }else if ( origValues.isEmpty() )
                 origValues.append(" ");
-            if( (*it).contains(" ") || (*it).contains("\t") || (*it).contains("\n") )
-                origValues.append( "\""+*it+"\"" );
+            QString newval = *it;
+            QRegExp re("([^$])\\$([^$\\(\\)\\{\\} /]*)( |\\)|/)");
+            newval.replace(re, "\1$(\\2)\\3");
+            if( (newval).contains(" ") || (newval).contains("\t") || (newval).contains("\n") )
+                origValues.append( "\""+newval+"\"" );
             else
-                origValues.append( *it );
+                origValues.append( newval );
             origValues.append( "\n" );
-        } else if ( origValues.contains( *it ) && remove )
+        } else if ( origValues.findIndex( *it ) != -1 && remove )
         {
             QStringList::iterator posit = origValues.find( *it );
             posit = origValues.remove( posit );
@@ -682,6 +736,9 @@ void Scope::updateVariable( const QString& variable, const QString& op, const QS
     if ( !m_root || listIsEmpty( values ) )
         return ;
 
+    if( m_varCache.contains( variable ) )
+        m_varCache.erase( variable );
+
     for ( int i = m_root->m_children.count() - 1; i >= 0; --i )
     {
         if ( m_root->m_children[ i ] ->nodeType() == QMake::AST::AssignmentAST )
@@ -701,7 +758,7 @@ void Scope::updateVariable( const QString& variable, const QString& op, const QS
             {
                 for ( QStringList::const_iterator it = values.begin() ; it != values.end() ; ++it )
                 {
-                    if ( op == "+=" && !removeFromOp && assignment->values.contains( *it ) )
+                    if ( op == "+=" && !removeFromOp && assignment->values.findIndex( *it ) != -1 )
                     {
                         if ( assignment->op == "=" )
                         {
@@ -719,7 +776,7 @@ void Scope::updateVariable( const QString& variable, const QString& op, const QS
                             }
                         }
                     }
-                    else if ( op == "-=" && !removeFromOp && assignment->values.contains( *it ) )
+                    else if ( op == "-=" && !removeFromOp && assignment->values.findIndex( *it ) != -1 )
                     {
                         updateValues( assignment->values, QStringList( *it ), true, assignment->indent );
                         if ( listIsEmpty( assignment->values ) )
@@ -736,7 +793,7 @@ void Scope::updateVariable( const QString& variable, const QString& op, const QS
                             m_root->removeChildAST( assignment );
                             delete assignment;
                         }
-                        else if ( assignment->op == "+=" && assignment->values.contains( *it ) )
+                        else if ( assignment->op == "+=" && assignment->values.findIndex( *it ) != -1 )
                         {
                             updateValues( assignment->values, QStringList( *it ), true, assignment->indent );
                             if ( listIsEmpty( assignment->values ) )
@@ -763,7 +820,7 @@ void Scope::updateVariable( const QString& variable, const QString& op, const QS
         else
             ast->setDepth( m_root->depth()+1 );
         m_root->addChildAST( ast );
-        if ( !values.contains( "\n" ) )
+        if ( values.findIndex( "\n" ) == -1 )
         {
             ast->values.append("\n");
         }
@@ -781,7 +838,7 @@ QValueList<QMake::AST*>::iterator Scope::findExistingVariable( const QString& va
         if ( ( *it ) ->nodeType() == QMake::AST::AssignmentAST )
         {
             QMake::AssignmentAST * assignment = static_cast<QMake::AssignmentAST*>( *it );
-            if ( assignment->scopedID == variable && ops.contains( assignment->op ) )
+            if ( assignment->scopedID == variable && ops.findIndex( assignment->op ) != -1 )
             {
                 return it;
             }
@@ -795,7 +852,9 @@ void Scope::init()
     if( !m_root )
         return;
 
+    kdDebug(9024) << "Initializing Scope: " << scopeName() << this << endl;
     m_maxCustomVarNum = 1;
+    m_unfinishedScopes = new QValueList<Scope*>();
 
     QValueList<QMake::AST*>::const_iterator it;
     for ( it = m_root->m_children.begin(); it != m_root->m_children.end(); ++it )
@@ -803,20 +862,23 @@ void Scope::init()
         if ( ( *it ) ->nodeType() == QMake::AST::ProjectAST )
         {
             QMake::ProjectAST * p = static_cast<QMake::ProjectAST*>( *it );
-            m_scopes.insert( getNextScopeNum(), new Scope( getNextScopeNum(), this, p, m_part ) );
+            m_scopes.insert( getNextScopeNum(), new Scope( getNextScopeNum(), this, p, m_defaultopts, m_part ) );
         }
         else if ( ( *it ) ->nodeType() == QMake::AST::IncludeAST )
         {
             QMake::IncludeAST * i = static_cast<QMake::IncludeAST*>( *it );
+            QString filename = i->projectName;
             if( i->projectName.startsWith("$") )
-                continue;
-            m_scopes.insert( getNextScopeNum(), new Scope( getNextScopeNum(), this, i, projectDir(), i->projectName, m_part ) );
+            {
+                filename = resolveVariables(i->projectName, *it);
+            }
+            m_scopes.insert( getNextScopeNum(), new Scope( getNextScopeNum(), this, i, projectDir(), filename, m_defaultopts, m_part ) );
         }
         else if ( ( *it ) ->nodeType() == QMake::AST::AssignmentAST )
         {
             QMake::AssignmentAST * m = static_cast<QMake::AssignmentAST*>( *it );
             // Check wether TEMPLATE==subdirs here too!
-            if ( m->scopedID == "SUBDIRS" && variableValues("TEMPLATE").contains("subdirs") )
+            if ( m->scopedID == "SUBDIRS" && variableValues("TEMPLATE").findIndex("subdirs") != -1 )
             {
                 for ( QStringList::const_iterator sit = m->values.begin() ; sit != m->values.end(); ++sit )
                 {
@@ -825,6 +887,9 @@ void Scope::init()
                         continue;
                     QDir subproject;
                     QString projectfile;
+                    kdDebug(9024) << "reading subproject: " << str << endl;
+                    if( str.startsWith("$") )
+                        str = resolveVariables(str, *it);
                     if( str.endsWith(".pro") )
                     {
                         subproject = QDir( projectDir(), "*.pro", QDir::Name | QDir::IgnoreCase, QDir::Files );
@@ -845,31 +910,31 @@ void Scope::init()
                             }else
                                 continue;
                         }
-                        if ( subproject.entryList().isEmpty() || subproject.entryList().contains( *sit + ".pro" ) )
-                            projectfile = (*sit) + ".pro";
+                        if ( subproject.entryList().isEmpty() || subproject.entryList().findIndex( str + ".pro" ) != -1 )
+                            projectfile = (str) + ".pro";
                         else
                             projectfile = subproject.entryList().first();
 
                     }
                     kdDebug( 9024 ) << "Parsing subproject: " << projectfile << endl;
-                    m_scopes.insert( getNextScopeNum(),
-                                     new Scope( getNextScopeNum(), this, subproject.absFilePath( projectfile ),
-                                                m_part, ( m->op != "-=" )) );
+                    m_scopes.insert( getNextScopeNum(), new Scope( getNextScopeNum(), this,
+                                                subproject.absFilePath( projectfile ),
+                                         m_part, ( m->op != "-=" )) );
                 }
             }
             else
             {
                 if ( !(
-                         KnownVariables.contains( m->scopedID )
+                         KnownVariables.findIndex( m->scopedID ) != -1
                          && ( m->op == "=" || m->op == "+=" || m->op == "-=")
                        )
                       && !(
                             ( m->scopedID.contains( ".files" ) || m->scopedID.contains( ".path" ) )
-                            && variableValues("INSTALLS").contains(m->scopedID.left( m->scopedID.findRev(".") ) )
+                            && variableValues("INSTALLS").findIndex(m->scopedID.left( m->scopedID.findRev(".") != -1 ) )
                           )
                       && !(
                             ( m->scopedID.contains( ".subdir" ) )
-                            && variableValues("SUBDIRS").contains(m->scopedID.left( m->scopedID.findRev(".") ) )
+                            && variableValues("SUBDIRS").findIndex(m->scopedID.left( m->scopedID.findRev(".") != -1 ) )
                           )
                     )
                 {
@@ -902,12 +967,6 @@ QString Scope::projectDir() const
     }
 }
 
-// const QValueList<Scope*> Scope::scopesInOrder() const
-// {
-//     return m_scopes->values();
-// }
-
-
 const QMap<unsigned int, QMap<QString, QString> > Scope::customVariables() const
 {
     QMap<unsigned int, QMap<QString, QString> > result;
@@ -934,6 +993,8 @@ void Scope::updateCustomVariable( unsigned int id, const QString& name, const QS
     {
         m_customVariables[ id ] ->values.clear();
         updateValues( m_customVariables[ id ] ->values, newvalues );
+        if( m_varCache.contains( m_customVariables[ id ]->scopedID ) )
+            m_varCache.erase( m_customVariables[ id ]->scopedID );
         m_customVariables[ id ] ->op = newop;
         m_customVariables[ id ] ->scopedID = name;
     }
@@ -1072,6 +1133,8 @@ void Scope::reloadProject()
 
     m_customVariables.clear();
 
+    m_varCache.clear();
+
     if ( m_root->isProject() )
         delete m_root;
     if ( !loadFromFile( filename ) && !QFileInfo( filename ).exists() )
@@ -1079,6 +1142,7 @@ void Scope::reloadProject()
         m_root = new QMake::ProjectAST();
         m_root->setFileName( filename );
     }
+    init();
 }
 
 Scope* Scope::disableSubproject( const QString& dir)
@@ -1086,20 +1150,20 @@ Scope* Scope::disableSubproject( const QString& dir)
     if( !m_root || ( m_root->isProject() && !m_incast ) )
         return 0;
 
-    if( scopeType() != Scope::IncludeScope && variableValuesForOp( "SUBDIRS", "+=").contains( dir ) )
+    if( scopeType() != Scope::IncludeScope && variableValuesForOp( "SUBDIRS", "+=").findIndex( dir ) != -1 )
         removeFromPlusOp( "SUBDIRS", dir );
     else if( scopeType() != Scope::IncludeScope )
         removeFromPlusOp( "SUBDIRS", dir );
 
     QDir curdir( projectDir() );
 
-    if ( variableValues("TEMPLATE").contains( "subdirs" ) )
+    if ( variableValues("TEMPLATE").findIndex( "subdirs" ) != -1 )
     {
         curdir.cd(dir);
         QString filename;
         QStringList entries = curdir.entryList("*.pro", QDir::Files);
 
-        if ( !entries.isEmpty() && !entries.contains( curdir.dirName()+".pro" ) )
+        if ( !entries.isEmpty() && entries.findIndex( curdir.dirName()+".pro" )  != -1 )
             filename = curdir.absPath() + QString(QChar(QDir::separator()))+entries.first();
         else
             filename = curdir.absPath() + QString(QChar(QDir::separator()))+curdir.dirName()+".pro";
@@ -1115,6 +1179,266 @@ Scope* Scope::disableSubproject( const QString& dir)
     return 0;
 }
 
+QString Scope::resolveVariables( const QString& value ) const
+{
+    return resolveVariables(QStringList(value),  0).front();
+}
+
+
+QString Scope::resolveVariables( const QString& value, QMake::AST* stopHere ) const
+{
+    return resolveVariables(QStringList(value),  stopHere).front();
+}
+
+QStringList Scope::variableValues( const QString& variable, QMake::AST* stopHere ) const
+{
+    QStringList result;
+
+    if ( !m_root )
+        return result;
+
+    calcValuesFromStatements( variable, result, true, stopHere );
+    result.remove( "\\\n" );
+    result.remove( "\n" );
+    result = Scope::removeWhiteSpace(result);
+    return result;
+}
+
+QStringList Scope::resolveVariables( const QStringList& values, QMake::AST* stopHere ) const
+{
+    QStringList result = values;
+    QMap<QString, QStringList> variables;
+    for( QStringList::iterator it = result.begin(); it != result.end(); ++it )
+    {
+        QRegExp re("\\$\\$([^\\) /]*)( |\\)|/|$)");
+        int pos = 0;
+        while( pos >= 0 )
+        {
+            pos = re.search( (*it), pos );
+            if( pos > -1 )
+            {
+                if( !variables.contains( re.cap(1) ) )
+                    variables[re.cap(1)] = resolveVariables( variableValues( re.cap(1), stopHere ) );
+                pos += re.matchedLength();
+            }
+        }
+        re = QRegExp("\\$\\$\\{([^\\)\\}]*)\\}");
+        pos = 0;
+        while( pos >= 0 )
+        {
+            pos = re.search( (*it), pos );
+            if( pos > -1 )
+            {
+                if( !variables.contains( re.cap(1) ) )
+                    variables[re.cap(1)] = resolveVariables( variableValues( re.cap(1), stopHere ) );
+                pos += re.matchedLength();
+            }
+        }
+        for( QMap<QString, QStringList>::const_iterator it2 = variables.begin(); it2 != variables.end(); ++it2 )
+        {
+            for( QStringList::const_iterator it3 = it2.data().begin(); it3 != it2.data().end(); ++it3 )
+            {
+                (*it).replace(QRegExp( "\\$\\$"+it2.key() ), *it3 );
+                (*it).replace(QRegExp( "\\$\\{"+it2.key()+"\\}" ), *it3 );
+            }
+        }
+    }
+    return result;
+}
+
+void Scope::allFiles( const QString& projectDirectory, std::set<QString>& res )
+{
+    QString myRelPath = getRelativePath( projectDirectory, projectDir() );
+    if( variableValues("TEMPLATE").findIndex("subdirs") == -1 )
+    {
+        QStringList values = variableValues( "INSTALLS" );
+        QStringList::const_iterator it;
+        for ( it = values.begin(); it != values.end(); ++it )
+        {
+            if ( ( *it ) == "target" )
+                continue;
+
+            QStringList files = variableValues( *it + ".files" );
+            QStringList::iterator filesit = files.begin();
+            for ( ;filesit != files.end(); ++filesit )
+            {
+                QString file = myRelPath + QString(QChar(QDir::separator())) + *filesit;
+                if( file.contains("*") )
+                {
+                    QFileInfo fi( projectDirectory + QString( QChar( QDir::separator() ) ) + file );
+                    QDir absDir = fi.dir( true );
+                    absDir.setNameFilter( fi.fileName() );
+                    absDir.setFilter( QDir::Files | QDir::Readable | QDir::NoSymLinks );
+                    QStringList list = absDir.entryList();
+                    for( QStringList::const_iterator it = list.begin(); it != list.end(); ++it )
+                    {
+                        res.insert( getRelativePath( projectDirectory, absDir.path()+QString( QChar( QDir::separator() ) )+*it ) );
+                    }
+                }
+                else
+                {
+                    res.insert( file );
+                }
+            }
+        }
+
+        values = variableValues( "LEXSOURCES" );
+        for ( it = values.begin(); it != values.end(); ++it )
+        {
+            QString file = myRelPath + QString(QChar(QDir::separator())) + *it;
+            res.insert( file );
+        }
+
+        values = variableValues( "YACCSOURCES" );
+        for ( it = values.begin(); it != values.end(); ++it )
+        {
+            QString file = myRelPath + QString(QChar(QDir::separator())) + *it;
+            res.insert( file );
+        }
+
+        values = variableValues( "DISTFILES" );
+        for ( it = values.begin(); it != values.end(); ++it )
+        {
+            QString file = myRelPath + QString(QChar(QDir::separator())) + *it;
+            if( file.contains("*") )
+            {
+                QFileInfo fi( projectDirectory + QString( QChar( QDir::separator() ) ) + file );
+                QDir absDir = fi.dir( true );
+                absDir.setNameFilter( fi.fileName() );
+                absDir.setFilter( QDir::Files | QDir::Readable | QDir::NoSymLinks );
+                QStringList list = absDir.entryList();
+                for( QStringList::const_iterator it = list.begin(); it != list.end(); ++it )
+                {
+                    res.insert( getRelativePath( projectDirectory, absDir.path()+QString( QChar( QDir::separator() ) )+*it ) );
+                }
+            }
+            else
+            {
+                res.insert( file );
+            }
+        }
+
+        if ( isQt4Project() )
+        {
+            values = variableValues( "RESOURCES" );
+            for ( it = values.begin(); it != values.end(); ++it )
+            {
+                QString file = myRelPath + QString(QChar(QDir::separator())) + *it;
+                res.insert( file );
+            }
+        }
+        else
+        {
+            values = variableValues( "IMAGES" );
+            for ( it = values.begin(); it != values.end(); ++it )
+            {
+                QString file = myRelPath + QString(QChar(QDir::separator())) + *it;
+                res.insert( file );
+            }
+        }
+
+        values = variableValues( "TRANSLATIONS" );
+        for ( it = values.begin(); it != values.end(); ++it )
+        {
+            QString file = myRelPath + QString(QChar(QDir::separator())) + *it;
+            res.insert( file );
+        }
+
+        values = variableValues( "IDLS" );
+        for ( it = values.begin(); it != values.end(); ++it )
+        {
+            QString file = myRelPath + QString(QChar(QDir::separator())) + *it;
+            res.insert( file );
+        }
+
+        if ( m_part->isTMakeProject() )
+        {
+            values = variableValues( "INTERFACES" );
+            for ( it = values.begin(); it != values.end(); ++it )
+            {
+                QString file = myRelPath + QString(QChar(QDir::separator())) + *it;
+                res.insert( file );
+                if( QFileInfo(projectDir()+QString(QChar(QDir::separator())) + *it+".h").exists() )
+                    res.insert( file+".h" );
+            }
+        }
+        else
+        {
+            values = variableValues( "FORMS" );
+            for ( it = values.begin(); it != values.end(); ++it )
+            {
+                QString file = myRelPath + QString(QChar(QDir::separator())) + *it;
+                res.insert( file );
+                if( QFileInfo(projectDir()+QString(QChar(QDir::separator())) + *it+".h").exists() )
+                    res.insert( file+".h" );
+            }
+        }
+
+        values = variableValues( "SOURCES" );
+        for ( it = values.begin(); it != values.end(); ++it )
+        {
+            QString file = myRelPath + QString(QChar(QDir::separator())) + *it;
+            res.insert( file );
+        }
+
+        values = variableValues( "HEADERS" );
+        for ( it = values.begin(); it != values.end(); ++it )
+        {
+            QString file = myRelPath + QString(QChar(QDir::separator())) + *it;
+            res.insert( file );
+        }
+    }
+    QMap<unsigned int, Scope*>::const_iterator it = m_scopes.begin();
+    for( ; it != m_scopes.end(); ++it )
+    {
+        it.data()->allFiles( projectDirectory, res );
+    }
+}
+
+QStringList Scope::allFiles( const QString& projectDir )
+{
+    QStringList result;
+    std::set<QString> files;
+    allFiles( projectDir, files );
+    for( std::set<QString>::const_iterator it = files.begin(); it != files.end() ; ++it )
+        result.append( *it );
+    return result;
+}
+
+QString Scope::findCustomVarForPath( const QString& path )
+{
+    QString result;
+    if( !m_root )
+        return result;
+
+    QMap<unsigned int, QMake::AssignmentAST*>::const_iterator it = m_customVariables.begin();
+    for( ; it != m_customVariables.end(); ++it )
+    {
+        kdDebug(9024) << "Checking " << path << " against " << removeWhiteSpace(it.data()->values) << endl;
+        if( !it.data()->values.isEmpty() && removeWhiteSpace(it.data()->values).front() == path )
+        {
+            return it.data()->scopedID;
+        }
+    }
+    if( scopeType() != ProjectScope )
+    {
+        return parent()->findCustomVarForPath( path );
+    }
+    return result;
+}
+
+void Scope::loadDefaultOpts()
+{
+    if( !m_defaultopts && m_root )
+    {
+        m_defaultopts = new QMakeDefaultOpts();
+        if( DomUtil::readBoolEntry( *m_part->projectDom(), "/kdevtrollproject/qmake/disableDefaultOpts", true ) )
+        {
+            m_defaultopts->readVariables( m_part->qmakePath(), QFileInfo( m_root->fileName() ).dirPath( true ) );
+        }
+    }
+}
+
 #ifdef DEBUG
 void Scope::printTree()
 {
@@ -1192,12 +1516,6 @@ void Scope::PrintAST::processNewLine( QMake::NewLineAST* n)
     QMake::ASTVisitor::processNewLine(n);
 }
 
-void Scope::PrintAST::processOrOperator( QMake::OrOperatorAST* n)
-{
-    kdDebug(9024) << getIndent() << "OrOperator " << endl;
-    QMake::ASTVisitor::processOrOperator(n);
-}
-
 void Scope::PrintAST::processComment( QMake::CommentAST* a)
 {
     kdDebug(9024) << getIndent() << "Comment: " << replaceWs(a->comment) << endl;
