@@ -25,11 +25,16 @@
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <kdirwatch.h>
+#include <kstatusbar.h>
 #include <qmessagebox.h>
 #include <kdevgenericfactory.h>
 #include <kaction.h>
 #include <kparts/part.h>
 #include <kprocess.h>
+#include <kurlrequesterdlg.h>
+#include <kurlrequester.h>
+#include <kurlcompletion.h>
+#include <kfile.h>
 #include <makeoptionswidget.h>
 
 
@@ -114,16 +119,20 @@ TrollProjectPart::TrollProjectPart(QObject *parent, const char *name, const QStr
                               "Environment variables and make arguments can be specified "
                               "in the project settings dialog, <b>Make Options</b> tab."));
 
+    action = new KAction( i18n("&Dist-Clean Project"), 0,
+                          m_widget, SLOT(slotDistCleanProject()),
+                          actionCollection(), "build_distclean_project" );
+    action->setToolTip(i18n("Dist-Clean project"));
+    action->setWhatsThis(i18n("<b>Dist-Clean project</b><p>Runs <b>make distclean</b> command from the "
+                              "project directory.<br>Environment variables and make arguments can be specified "
+                              "in the project settings dialog, <b>Make Options</b> tab."));
+
     action = new KAction( i18n("Execute Main Program"), "exec", SHIFT+Key_F9,
                           this, SLOT(slotBuildAndExecuteProject()),
                           actionCollection(), "build_execute_project" );
     action->setToolTip(i18n("Execute main program"));
     action->setWhatsThis(i18n("<b>Execute program</b><p>Executes the main program specified in project settings, <b>Run Options</b> tab."));
 
-
-
-
-
     action = new KAction( i18n("&Build Subproject"), "make_kdevelop", Key_F7,
                           m_widget, SLOT(slotBuildTarget()),
                           actionCollection(), "build_build_target" );
@@ -151,6 +160,15 @@ TrollProjectPart::TrollProjectPart(QObject *parent, const char *name, const QStr
                               "Environment variables and make arguments can be specified "
                               "in the project settings dialog, <b>Make Options</b> tab."));
 
+    action = new KAction( i18n("&Dist-Clean Subproject"), 0,
+                          m_widget, SLOT(slotDistCleanTarget()),
+                          actionCollection(), "build_distclean_target" );
+    action->setToolTip(i18n("Dist-Clean subproject"));
+    action->setWhatsThis(i18n("<b>Dist-Clean subproject</b><p>Runs <b>make distclean</b> from the current"
+                              " subproject directory. Current subproject is a subproject selected in <b>QMake manager</b> 'overview' window.<br>"
+                              "Environment variables and make arguments can be specified "
+                              "in the project settings dialog, <b>Make Options</b> tab."));
+
     action = new KAction( i18n("Execute Subproject"), "exec", 0,
                           this, SLOT(slotBuildAndExecuteTarget()),
                           actionCollection(), "build_execute_target" );
@@ -165,17 +183,21 @@ TrollProjectPart::TrollProjectPart(QObject *parent, const char *name, const QStr
     connect( makeFrontend(), SIGNAL(commandFinished(const QString&)),
              this, SLOT(slotCommandFinished(const QString&)) );
 
-    m_qmakeHeader = i18n("# File generated by kdevelop's qmake manager. \n"
-                         "# ------------------------------------------- \n"
-                         "# Subdir relative project main directory: %s\n"
-                         "# Target is %s %s\n");
+    QString m_defaultQtDir = DomUtil::readEntry(*projectDom(), "/kdevcppsupport/qt/root", "");
+    QString m_qmakePath = DomUtil::readEntry(*projectDom(), "/kdevcppsupport/qt/qmake", "");
 
-    m_availableQtDirList = availableQtDirList();
-    m_defaultQtDir = DomUtil::readEntry(*projectDom(), "/kdevcppsupport/qt/root", "");
-    if( m_defaultQtDir.isEmpty() )
-        m_defaultQtDir = ::getenv( "QTDIR" );
-    if( m_defaultQtDir.isEmpty() && !m_availableQtDirList.isEmpty() )
-        m_defaultQtDir = m_availableQtDirList.front();
+    if( m_defaultQtDir.isEmpty() || !isValidQtDir( m_defaultQtDir ) )
+    {
+        m_defaultQtDir = findQtDir();
+        kdDebug(9024) << "Setting default dir to: " << m_defaultQtDir << endl;
+        DomUtil::writeEntry(*projectDom(), "/kdevcppsupport/qt/root", m_defaultQtDir );
+    }
+    if( m_qmakePath.isEmpty() || !isExecutable( m_qmakePath ) )
+    {
+        m_qmakePath = findExecutable( "qmake" );
+        kdDebug(9024) << "Setting qmake binary to: " << m_qmakePath << endl;
+        DomUtil::writeEntry(*projectDom(), "/kdevcppsupport/qt/qmake", m_qmakePath );
+    }
 }
 
 
@@ -215,9 +237,9 @@ QString TrollProjectPart::makeEnvironment()
         environstr += " ";
     }
 
-    if( !hasQtDir && !m_defaultQtDir.isEmpty() )
+    if( !hasQtDir && !isQt4Project() && !DomUtil::readEntry(*projectDom(), "/kdevcppsupport/qt/root", "").isEmpty() )
     {
-         environstr += QString( "QTDIR=" ) + EnvVarTools::quote( m_defaultQtDir ) + QString( " " );
+         environstr += QString( "QTDIR=" ) + EnvVarTools::quote( DomUtil::readEntry(*projectDom(), "/kdevcppsupport/qt/root", "") ) + QString( " " );
     }
 
     return environstr;
@@ -244,7 +266,114 @@ void TrollProjectPart::projectConfigWidget(KDialogBase *dlg)
 
 void TrollProjectPart::openProject(const QString &dirName, const QString &projectName)
 {
+    mainWindow()->statusBar()->message( i18n("Loading Project...") );
+
+    QString defaultQtDir = DomUtil::readEntry(*projectDom(), "/kdevcppsupport/qt/root", "");
+    if( !isQt4Project() && ( defaultQtDir.isEmpty() || !isValidQtDir( defaultQtDir ) ) )
+    {
+        bool doask = true;
+        while( doask )
+        {
+            KURLRequesterDlg dlg( i18n("Choose Qt3 directory"),
+                i18n("Choose the Qt3 directory to use. This directory needs to have an include directory containing qt.h.")
+                                  , m_widget, 0);
+            dlg.urlRequester() ->setMode( KFile::Directory | KFile::LocalOnly );
+            dlg.urlRequester() ->setURL( QString::null );
+            dlg.urlRequester() ->completionObject() ->setDir( "/" );
+
+            if ( dlg.exec() == QDialog::Accepted && !dlg.urlRequester() ->url().isEmpty() )
+            {
+                QString qtdir = dlg.urlRequester()->url();
+                if( !isValidQtDir( qtdir ) )
+                {
+                    if( KMessageBox::warningYesNo( m_widget,
+                                                i18n("The directory you gave is not a proper Qt directory, the "
+                                                    "project might not work properly without one.\nPlease make "
+                                                    "sure you give a directory that contains a bin with the "
+                                                    "qmake binary in it and for Qt3 project also contains an "
+                                                    "include directory with qt.h in it.\nDo you want to try "
+                                                    "setting a Qt directory again?"),
+                                                i18n("Wrong Qt directory given"))
+                        == KMessageBox::Yes
+                    )
+                    doask = true;
+                else
+                    doask = false;
+                }else
+                {
+                    defaultQtDir = qtdir;
+                    doask = false;
+                }
+
+            }else
+            {
+                if( KMessageBox::warningYesNo( m_widget,
+                                               i18n("You didn't specify a Qt directory, the project might not "
+                                                   "work properly without one.\nDo you want to try setting a Qt"
+                                                   " directory again?"),
+                                               i18n("No Qt directory given"))
+                        == KMessageBox::Yes
+                    )
+                    doask = true;
+                else
+                    doask = false;
+            }
+        }
+    }
+    QString qmakePath = DomUtil::readEntry(*projectDom(), "/kdevcppsupport/qt/qmake", "");
+    if( qmakePath.isEmpty() || !isExecutable( qmakePath ) )
+    {
+        bool doask = true;
+        while( doask )
+        {
+            KURLRequesterDlg dlg( i18n("Choose QMake executable"),
+                i18n("Choose the QMake binary to use. QMake is used to generate Makefiles from the project files."), m_widget, 0);
+            dlg.urlRequester() ->setMode( KFile::Directory | KFile::LocalOnly );
+            dlg.urlRequester() ->setURL( QString::null );
+            dlg.urlRequester() ->completionObject() ->setDir( "/" );
+
+            if ( dlg.exec() == QDialog::Accepted && !dlg.urlRequester() ->url().isEmpty() )
+            {
+                QString qmake = dlg.urlRequester()->url();
+                if( !isExecutable( qmake ) )
+                {
+                    if( KMessageBox::warningYesNo( m_widget,
+                                                i18n("The binary you gave is not executable, the "
+                                                    "project might not work properly.\nPlease make "
+                                                    "sure you give a qmake binary that is executable.\nDo you want to try "
+                                                    "setting the QMake binary again?"),
+                                                i18n("Wrong QMake binary given"))
+                        == KMessageBox::Yes
+                    )
+                    doask = true;
+                else
+                    doask = false;
+                }else
+                {
+                    qmakePath = qmake;
+                    doask = false;
+                }
+
+            }else
+            {
+                if( KMessageBox::warningYesNo( m_widget,
+                                               i18n("You didn't specify a QMake binary, the project might not "
+                                                   "work properly without one.\nDo you want to try setting a QMake"
+                                                   " binary again?"),
+                                               i18n("No QMake binary given"))
+                        == KMessageBox::Yes
+                    )
+                    doask = true;
+                else
+                    doask = false;
+            }
+        }
+    }
+    DomUtil::writeEntry( *projectDom(), "/kdevcppsupport/qt/root", defaultQtDir );
+    DomUtil::writeEntry( *projectDom(), "/kdevcppsupport/qt/qmake", qmakePath );
+
     m_widget->openProject(dirName);
+
     m_projectName = projectName;
 
     QDomDocument &dom = *projectDom();
@@ -406,7 +535,7 @@ void TrollProjectPart::addFile(const QString &fileName)
 	QStringList fileList;
 	fileList.append ( fileName );
 
-	this->addFiles ( fileList );
+    this->addFiles ( QStringList( fileName ) );
 }
 
 void TrollProjectPart::addFiles ( const QStringList &fileList )
@@ -509,8 +638,7 @@ void TrollProjectPart::startQMakeCommand(const QString &dir)
     	cmdline = "tmake ";
     }else
     {
-      cmdline = DomUtil::readEntry(*projectDom(), "/kdevcppsupport/qt/root", "")+QString( QChar( QDir::separator() ) )+"bin"+QString( QChar( QDir::separator() ) );
-	cmdline += "qmake ";
+      cmdline = DomUtil::readEntry(*projectDom(), "/kdevcppsupport/qt/qmake", "")+" ";
     }
 
     //QString cmdline = QString::fromLatin1( isTMakeProject() ? "tmake " : "qmake " );
@@ -587,27 +715,81 @@ KDevProject::Options TrollProjectPart::options( ) const
 
 bool TrollProjectPart::isValidQtDir( const QString& path ) const
 {
-  return QFile::exists( path + QString( QChar( QDir::separator() ) )+"include"+QString( QChar( QDir::separator() ) )+"qt.h" ) || QFile::exists( path +
-                        QString( QChar( QDir::separator() ) )+"include"+QString( QChar( QDir::separator() ) )+"Qt"+QString( QChar( QDir::separator() ) )+"qglobal.h" ) ;
+    QFileInfo inc( path + QString( QChar( QDir::separator() ) )+
+                   "include"+QString( QChar( QDir::separator() ) )+
+                   "qt.h" );
+    return ( isQt4Project() || ( !isQt4Project() && inc.exists() ) );
 }
 
-QStringList TrollProjectPart::availableQtDirList() const
+void TrollProjectPart::buildBinDirs( QStringList & dirs ) const
 {
-    QStringList qtdirs, lst;
-    qtdirs.push_back( ::getenv("QTDIR") );
-    qtdirs.push_back( QDir::rootDirPath()+"usr"+QString( QChar( QDir::separator() ) )+"lib"+QString( QChar( QDir::separator() ) )+"qt3" );
+    if( !isQt4Project() )
+    {
+        QString m_defaultQtDir = DomUtil::readEntry(*projectDom(), "/kdevcppsupport/qt/root", "");
+        if( !m_defaultQtDir.isEmpty() )
+            dirs << (m_defaultQtDir + QString( QChar( QDir::separator() ) ) + "bin" );
+        dirs << ( ::getenv("QTDIR") + QString( QChar( QDir::separator() ) ) + "bin" );
+    }
+    QStringList paths = QStringList::split(":",::getenv("PATH"));
+    dirs += paths;
+    QString binpath = QDir::rootDirPath() + "bin";
+    if( dirs.findIndex( binpath ) != -1 )
+        dirs << binpath;
+
+    binpath = QDir::rootDirPath() + "usr" + QString( QChar( QDir::separator() ) ) + "bin";
+    if( dirs.findIndex( binpath ) != -1 )
+        dirs << binpath;
+    binpath = QDir::rootDirPath() + "usr" + QString( QChar( QDir::separator() ) ) + "local" + QString( QChar( QDir::separator() ) ) + "bin";
+    if( dirs.findIndex( binpath ) != -1 )
+        dirs << binpath;
+}
+
+
+QString TrollProjectPart::findExecutable( const QString& execname ) const
+{
+    QStringList dirs;
+    buildBinDirs( dirs );
+
+    for( QStringList::Iterator it=dirs.begin(); it!=dirs.end(); ++it )
+    {
+        QString designer = *it + QString( QChar( QDir::separator() ) ) + execname;
+        if( !designer.isEmpty() && isExecutable( designer ) )
+        {
+            return designer;
+        }
+    }
+    return "";
+}
+
+bool TrollProjectPart::isExecutable( const QString& path ) const
+{
+    QFileInfo fi(path);
+    return( fi.exists() && fi.isExecutable() );
+}
+
+QString TrollProjectPart::findQtDir()
+{
+    QStringList qtdirs;
+    if( !isQt4Project() )
+        qtdirs.push_back( ::getenv("QTDIR") );
+    qtdirs.push_back( QDir::rootDirPath()+"usr"+QString( QChar( QDir::separator() ) )+"lib"+QString( QChar( QDir::separator() ) )+"qt"+QString("%1").arg( DomUtil::readEntry( *projectDom(), "/kdevcppsupport/qt/version", "3") ) );
+    qtdirs.push_back( QDir::rootDirPath()+"usr"+QString( QChar( QDir::separator() ) )+"lib"+QString( QChar( QDir::separator() ) )+"qt"+QString( QChar( QDir::separator() ) )+QString("%1").arg( DomUtil::readEntry( *projectDom(), "/kdevcppsupport/qt/version", "3") ) );
+    qtdirs.push_back( QDir::rootDirPath()+"usr"+QString( QChar( QDir::separator() ) )+"share"+QString( QChar( QDir::separator() ) )+"qt"+QString("%1").arg( DomUtil::readEntry( *projectDom(), "/kdevcppsupport/qt/version", "3") ) );
+    qtdirs.push_back( QDir::rootDirPath()+"usr" );
     qtdirs.push_back( QDir::rootDirPath()+"usr"+QString( QChar( QDir::separator() ) )+"lib"+QString( QChar( QDir::separator() ) )+"qt" );
-    qtdirs.push_back( QDir::rootDirPath()+"usr"+QString( QChar( QDir::separator() ) )+"share"+QString( QChar( QDir::separator() ) )+"qt3" );
 
     for( QStringList::Iterator it=qtdirs.begin(); it!=qtdirs.end(); ++it )
     {
         QString qtdir = *it;
         if( !qtdir.isEmpty() && isValidQtDir(qtdir) )
-	    lst.push_back( qtdir );
+        {
+            return qtdir;
+        }
     }
-    return lst;
+    return "";
 }
 
+
 QStringList recursiveProFind( const QString &currDir, const QString &baseDir )
 {
 	QStringList fileList;
