@@ -98,11 +98,13 @@ public slots:
     void slotBuildTarget();
     void slotRebuildTarget();
     void slotCleanTarget();
+    void slotDistCleanTarget();
     void slotExecuteTarget();
 
     void slotBuildProject();
     void slotRebuildProject();
     void slotCleanProject();
+    void slotDistCleanProject();
     void slotExecuteProject();
 
     void slotBuildOpenFile();
@@ -130,10 +132,14 @@ private slots:
     void slotDisableSubproject( QMakeScopeItem* spitem = 0 );
     void slotProjectDirty( const QString& );
 
+    void createQMakeScopeItems();
+
 private:
     void cleanDetailView( QMakeScopeItem *item );
+    void runClean( QMakeScopeItem*, const QString& );
     void buildProjectDetailTree( QMakeScopeItem *item, KListView *listviewControl );
     void removeFile( QMakeScopeItem *spitem, FileItem *fitem );
+    void addSubprojectToItem( QMakeScopeItem*, const QString& );
     void setupContext();
     //     void parseScope(QMakeScopeItem *item,QString scopeString, Scope *scope);
     GroupItem* getInstallRoot( QMakeScopeItem *item );
@@ -148,6 +154,7 @@ private:
     /*fileName: full base file name like QFileInfo::baseName ( true )*/
     QPtrList<QMakeScopeItem> findSubprojectForFile( QFileInfo fi );
     void findSubprojectForFile( QPtrList<QMakeScopeItem> &list, QMakeScopeItem * item, QString absFilePath );
+    QMakeScopeItem* findSubprojectForPath( const QString& );
     //    QString makeEnvironment();
 
     TrollProjectWidget::SaveType dialogSaveBehaviour() const;
@@ -190,6 +197,9 @@ private:
 
     TrollProjectView m_lastFocusedView;
 
+    bool m_filesCached;
+    QStringList m_allFilesCache;
+
     friend class ChooseSubprojectDlg;
     friend class ProjectConfigurationDlg;
 };
