@@ -3,7 +3,7 @@
 
 
 #include <qwidget.h>
-
+#include <ktrader.h>
 
 #include "editchooser.h"
 
@@ -26,6 +26,9 @@ private slots:
 
     void accept();
 
+private:
+	KTrader::OfferList m_offers;
+
 };
 
 
