@@ -14,7 +14,6 @@
 #include "cppsupport_events.h"
 #include "codeinformationrepository.h"
 #include "cppcodecompletion.h"
-#include "driver.h"
 #include "ast_utils.h"
 #include "kdevdeepcopy.h"
 #include "kdevdriver.h"
@@ -36,7 +35,6 @@
 #include <qfile.h>
 #include <qfileinfo.h>
 #include <qtextstream.h>
-#include <qprocess.h>
 #include <list>
 
 
@@ -108,8 +106,17 @@ public:
 	
 	virtual bool isModified( const QString& fileName )
 	{
-		Q_UNUSED( fileName );
-		return true;
+		bool ret = false;
+		kapp->lock ();
+
+		KParts::ReadOnlyPart *part = m_cppSupport->partController()->partForURL( KURL(fileName) );
+		KTextEditor::Document * doc = dynamic_cast<KTextEditor::Document*>( part );
+
+		if ( doc )
+			ret = doc->isModified();
+
+		kapp->unlock();
+		return ret;
 	}
 	
 private:
@@ -227,7 +234,7 @@ private:
 };
 
 BackgroundParser::BackgroundParser( CppSupportPart* part, QWaitCondition* consumed )
-: m_consumed( consumed ), m_cppSupport( part ), m_close( false )
+: m_consumed( consumed ), m_cppSupport( part ), m_close( false ), m_saveMemory( false )
 {
 	m_fileList = new SynchronizedFileList();
 	m_driver = new KDevDriver( m_cppSupport );
@@ -391,6 +398,7 @@ ParsedFilePointer BackgroundParser::translationUnit( const QString& fileName )
 
 QValueList<Problem> BackgroundParser::problems( const QString& fileName, bool readFromDisk, bool forceParse )
 {
+    Q_UNUSED(readFromDisk);
 	Unit * u = findUnit( fileName );
 	if ( u == 0 || forceParse )
 	{
@@ -431,11 +439,11 @@ int BackgroundParser::countInQueue( const QString& file ) const {
 void BackgroundParser::updateParserConfiguration()
 {
 	QMutexLocker locker( &m_mutex );
-	
+
 	m_driver->setup();
 	QString conf_file_name = m_cppSupport->specialHeaderName();
 	m_driver->removeAllMacrosInFile( conf_file_name );
-	m_driver->parseFile( conf_file_name, true, true );
+	m_driver->parseFile( conf_file_name, true, true, true );
 }
 
 void BackgroundParser::run()
@@ -447,6 +455,11 @@ void BackgroundParser::run()
 		
 		while ( m_fileList->isEmpty() )
 		{
+			if( m_saveMemory ) {
+				m_saveMemory = false;
+				m_driver->lexerCache()->saveMemory();
+			}
+
 			m_canParse.wait();
 			
 			if ( m_close )
@@ -473,4 +486,9 @@ void BackgroundParser::run()
 //	QThread::exit();
 }
 
+void BackgroundParser::saveMemory() {
+	m_saveMemory = true; //Delay the operation
+	m_canParse.wakeAll();
+}
+
 //kate: indent-mode csands; tab-width 4; space-indent off;
