@@ -8,7 +8,7 @@
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
-***************************************************************************/ 
+***************************************************************************/
 // qt includes
 #include <qtabwidget.h>
 #include <qbuttongroup.h>
@@ -36,7 +36,7 @@
 #include <knuminput.h>
 #include <kmainwindow.h>
 #include <klineedit.h>
-#include <kdeversion.h> 
+#include <kdeversion.h>
 // kdevelop includes
 #include <domutil.h>
 #include <kdevcoderepository.h>
@@ -67,11 +67,21 @@ CCConfigWidget::CCConfigWidget( CppSupportPart* part, QWidget* parent, const cha
 	connect( m_pPart->codeRepository(), SIGNAL( catalogUnregistered( Catalog* ) ),
 	         this, SLOT( catalogUnregistered( Catalog* ) ) );
 
-	connect( m_qtDir, SIGNAL(urlSelected(const QString &)), 
+	connect( m_qtDir, SIGNAL(urlSelected(const QString &)),
 		 this, SLOT(isValidQtDir(const QString &)));
-	connect( m_qtDir, SIGNAL(textChanged(const QString &)), 
+	connect( m_qtDir, SIGNAL(textChanged(const QString &)),
 		 this, SLOT(isValidQtDir(const QString &)));
 
+    connect( m_designerPath, SIGNAL(urlSelected(const QString &)),
+         this, SLOT(isExecutable(const QString &)));
+    connect( m_designerPath, SIGNAL(textChanged(const QString &)),
+         this, SLOT(isExecutable(const QString &)));
+
+    connect( m_qmakePath, SIGNAL(urlSelected(const QString &)),
+         this, SLOT(isExecutable(const QString &)));
+    connect( m_qmakePath, SIGNAL(textChanged(const QString &)),
+         this, SLOT(isExecutable(const QString &)));
+
 	initGeneralTab( );
 	initQtTab();
 	initCodeCompletionTab( );
@@ -160,12 +170,12 @@ void CCConfigWidget::initCodeCompletionTab( )
 	{
 		Catalog* c = *it;
 		QFileInfo dbInfo( c->dbName() );
-		QCheckListItem* item = new QCheckListItem( advancedOptions, KURL::decode_string( dbInfo.baseName() ), QCheckListItem::CheckBox );
+		QCheckListItem* item = new QCheckListItem( advancedOptions, KURL::decode_string( dbInfo.baseName(true) ), QCheckListItem::CheckBox );
 		item->setOn( c->enabled() );
 
 		m_catalogs[ item ] = c;
 	}
-	
+
 	checkPreprocessIncludedHeaders->setChecked( c->preProcessAllHeaders() );
 	checkListGlobalItems->setChecked( c->alwaysIncludeNamespaces() );
 	checkParseMissingHeaders->setChecked( c->parseMissingHeaders() );
@@ -188,7 +198,7 @@ void CCConfigWidget::saveCodeCompletionTab( )
 	c->setProcessFunctionArguments( checkCompleteArgumentType->isChecked() );
 	c->setProcessPrimaryTypes( checkCompleteReturnType->isChecked() );
 	//c->setShowOnlyAccessibleItems( checkShowOnlyAccessible->isChecked() );
-	
+
 	c->setNamespaceAliases( editNamespaceAlias->text() );
 	c->setShowEvaluationContextMenu( checkBox18->isChecked() );
 	c->setStatusBarTypeEvaluation( checkShowTypeEvaluationInStatusBar->isChecked() );
@@ -213,7 +223,7 @@ void CCConfigWidget::saveCodeCompletionTab( )
 	c->setParseMissingHeaders( checkParseMissingHeaders->isChecked() );
 	c->setResolveIncludePaths( checkResolveIncludePaths->isChecked() );
 	c->setCustomIncludePaths( editIncludePaths->text() );
-	
+
 	c->store();
 }
 
@@ -230,17 +240,17 @@ void CCConfigWidget::slotRemovePCS()
 		return ;
 
 	QString db = advancedOptions->selectedItem() ->text( 0 );
-	QString question = i18n( "Are you sure you want to remove the \"%1\" database?" ).arg( db );
+	QString question = i18n( "Are you sure you want to delete the \"%1\" database?" ).arg( db );
 
 	KStandardDirs *dirs = m_pPart->instance() ->dirs();
 	QString dbName = dirs->saveLocation( "data", "kdevcppsupport/pcs" ) + KURL::encode_string_no_slash( db ) + ".db";
-	
+
 #if KDE_VERSION >= KDE_MAKE_VERSION(3,3,0)
 
-	if ( KMessageBox::Continue == KMessageBox::warningContinueCancel( 0, question, i18n( "Remove Database" ), KStdGuiItem::del() ) )
+	if ( KMessageBox::Continue == KMessageBox::warningContinueCancel( 0, question, i18n( "Delete Database" ), KStdGuiItem::del() ) )
 #else
 
-	if ( KMessageBox::Continue == KMessageBox::warningContinueCancel( 0, question, i18n( "Remove Database" ),
+	if ( KMessageBox::Continue == KMessageBox::warningContinueCancel( 0, question, i18n( "Delete Database" ),
 			KGuiItem( i18n( "&Delete" ), "editdelete", i18n( "Delete item(s)" ) ) ) )
 #endif
 
@@ -252,7 +262,7 @@ void CCConfigWidget::slotRemovePCS()
 void CCConfigWidget::catalogRegistered( Catalog * c )
 {
 	QFileInfo dbInfo( c->dbName() );
-	QCheckListItem* item = new QCheckListItem( advancedOptions, KURL::decode_string( dbInfo.baseName() ), QCheckListItem::CheckBox );
+	QCheckListItem* item = new QCheckListItem( advancedOptions, KURL::decode_string( dbInfo.baseName(true) ), QCheckListItem::CheckBox );
 	item->setOn( c->enabled() );
 
 	m_catalogs[ item ] = c;
@@ -371,13 +381,13 @@ void CCConfigWidget::saveGetterSetterTab( )
 void CCConfigWidget::initSplitTab( )
 {
 	CppSplitHeaderSourceConfig * config = m_pPart->splitHeaderSourceConfig();
-	
+
 	if ( config == 0 )
 		return ;
-	
+
 	m_splitEnable->setChecked( config->splitEnabled() );
 	m_splitSync->setChecked( config->autoSync() );
-	
+
 	QString o = config->orientation();
 	m_splitVertical->setChecked( o == "Vertical" );
 	m_splitHorizontal->setChecked( o == "Horizontal" );
@@ -386,26 +396,27 @@ void CCConfigWidget::initSplitTab( )
 void CCConfigWidget::saveSplitTab( )
 {
 	CppSplitHeaderSourceConfig * config = m_pPart->splitHeaderSourceConfig();
-	
+
 	if ( config == 0 )
 		return ;
-	
+
 	config->setSplitEnable( m_splitEnable->isChecked() );
 	config->setAutoSync( m_splitSync->isChecked() );
-	
+
 	if ( m_splitVertical->isChecked() )
 		config->setOrientation( "Vertical" );
 	else if ( m_splitHorizontal->isChecked() )
 		config->setOrientation( "Horizontal" );
-	
+
 	config->store();
 }
 
 void CCConfigWidget::initQtTab()
 {
 	m_qtDir->setMode(KFile::Directory|KFile::ExistingOnly|KFile::LocalOnly);
-	
+
 	QtBuildConfig* c = m_pPart->qtBuildConfig();
+	c->init();
 
 	m_qtUsed->setChecked( c->isUsed() );
 	if( c->version() == 4 )
@@ -414,6 +425,11 @@ void CCConfigWidget::initQtTab()
 		m_kdevembedded->setEnabled( false );
 		m_kdevexternal->setEnabled( false );
 		m_qtStyleVersion4->setEnabled( true );
+        m_designerPath->setEnabled( true );
+        m_qmakePath->setEnabled( true );
+        m_qtDir->setEnabled( false );
+        m_txtQtDir->setEnabled( false );
+        m_txtDesigner->setEnabled( true );
 	}
 	else
 	{
@@ -421,6 +437,11 @@ void CCConfigWidget::initQtTab()
 		m_kdevembedded->setEnabled( true );
 		m_kdevexternal->setEnabled( true );
 		m_qtStyleVersion4->setEnabled( false );
+        m_designerPath->setEnabled( true );
+        m_qmakePath->setEnabled( true );
+        m_qtDir->setEnabled( true );
+        m_txtQtDir->setEnabled( true );
+        m_txtDesigner->setEnabled( true );
 	}
 	if( c->includeStyle() == 4 )
 	{
@@ -431,6 +452,10 @@ void CCConfigWidget::initQtTab()
 	}
 	m_qtDir->setURL( c->root() );
 	isValidQtDir(m_qtDir->url());
+    m_qmakePath->setURL( c->qmakePath() );
+    isExecutable( m_qmakePath->url() );
+    m_designerPath->setURL( c->designerPath() );
+    isExecutable( m_designerPath->url() );
 	if ( c->designerIntegration() == "EmbeddedKDevDesigner" )
 	{
 		m_kdevembedded->setChecked( true );
@@ -444,10 +469,39 @@ void CCConfigWidget::initQtTab()
 	}
 }
 
+bool CCConfigWidget::isExecutable( const QString& path )
+{
+    QFileInfo fi(path);
+
+    return ( fi.exists() && fi.isExecutable()  );
+}
+
+void CCConfigWidget::isQMakeExecutable( const QString& path )
+{
+    if( isExecutable( path ) )
+    {
+        m_qmakePath->lineEdit()->setPaletteForegroundColor(QColor("#ff0000"));
+    }else
+    {
+        m_qmakePath->lineEdit()->unsetPalette();
+    }
+}
+
+void CCConfigWidget::isDesignerExecutable( const QString& path )
+{
+    if( isExecutable( path ) )
+    {
+        m_designerPath->lineEdit()->setPaletteForegroundColor(QColor("#ff0000"));
+    }else
+    {
+        m_designerPath->lineEdit()->unsetPalette();
+    }
+}
+
 void CCConfigWidget::saveQtTab()
 {
 	QtBuildConfig* c = m_pPart->qtBuildConfig();
-	
+
 	c->setUsed( m_qtUsed->isChecked() );
 	if( m_versionQt4->isChecked() )
 	{
@@ -465,6 +519,8 @@ void CCConfigWidget::saveQtTab()
 		c->setIncludeStyle( 3 );
 	}
 	c->setRoot( m_qtDir->url() );
+    c->setQMakePath( m_qmakePath->url() );
+    c->setDesignerPath( m_designerPath->url() );
 	if( m_kdevembedded->isChecked() )
 	{
 		c->setDesignerIntegration( "EmbeddedKDevDesigner" );
@@ -481,7 +537,10 @@ void CCConfigWidget::saveQtTab()
 
 void CCConfigWidget::isValidQtDir( const QString &dir )
 {
-	if ( !QFile::exists( dir + "/include/qt.h" ) && !QFile::exists( dir + "/include/Qt/qglobal.h" ) )
+	QFileInfo inc( dir + QString( QChar( QDir::separator() ) )+
+			"include"+QString( QChar( QDir::separator() ) )+
+			"qt.h" );
+	if ( !m_versionQt4->isChecked() && !inc.exists() )
 	{
 		m_qtDir->lineEdit()->setPaletteForegroundColor(QColor("#ff0000"));
 	}else
@@ -506,6 +565,7 @@ void CCConfigWidget::toggleQtVersion( bool )
     m_kdevembedded->setEnabled( false );
     m_kdevexternal->setEnabled( false );
   }
+  isValidQtDir( m_qtDir->url() );
 }
 
 #include "ccconfigwidget.moc"
