@@ -182,15 +182,18 @@ CppSupportPart::CppSupportPart( QObject *parent, const char *name, const QString
 	connect( m_pCompletionConfig, SIGNAL( stored() ),
 	         this, SLOT( codeCompletionConfigStored() ) );
 	m_qtBuildConfig = new QtBuildConfig( this, projectDom() );
-        m_qtBuildConfig->store();
+    m_qtBuildConfig->store();
 
 	m_driver = new CppDriver( this );
 	m_problemReporter = 0;
 
 	m_deleteParserStoreTimer = new QTimer( this );
+	m_saveMemoryTimer = new QTimer( this );
 	m_functionHintTimer = new QTimer( this );
+	connect( m_saveMemoryTimer, SIGNAL(timeout()), this, SLOT(slotSaveMemory()) );
 	connect( m_deleteParserStoreTimer, SIGNAL(timeout()), this, SLOT(slotDeleteParserStore()) );
 	resetParserStoreTimer();
+	m_saveMemoryTimer->start( 240000, false ); //Free some memory every 4 minutes
 	//    connect( m_functionHintTimer, SIGNAL(timeout()), this, SLOT(slotFunctionHint()) );
 
 	setXMLFile( "kdevcppsupport.rc" );
@@ -470,7 +473,7 @@ void CppSupportPart::projectOpened( )
 
 	setupCatalog();
 
-	m_problemReporter = new ProblemReporter( this );
+	m_problemReporter = new ProblemReporter( this, 0, "problemReporterWidget" );
 	m_problemReporter->setIcon( SmallIcon( "info" ) );
 	m_problemReporter->setCaption( i18n( "Problem Reporter" ) );
 	mainWindow( ) ->embedOutputView( m_problemReporter, i18n( "Problems" ), i18n( "Problem reporter" ) );
@@ -512,7 +515,7 @@ void CppSupportPart::projectClosed( )
 	{
 		Catalog* c = *it;
 		if ( c->enabled() )
-			enabledPCSs.push_back( QFileInfo( c->dbName() ).baseName() );
+			enabledPCSs.push_back( QFileInfo( c->dbName() ).baseName(true) );
 	}
 	DomUtil::writeListEntry( *project() ->projectDom(), "kdevcppsupport/references", "pcs", enabledPCSs );
 
@@ -1018,6 +1021,15 @@ QString CppSupportPart::sourceOrHeaderCandidate( const KURL &url )
 	return QString::null;
 }
 
+void CppSupportPart::slotSaveMemory() {
+	if( m_backgroundParser ) {
+		///This is done so the caches are completely empty after kdevelop was idle for some time(else it would be waste of memory). The background-parsers internal lexer-cache-manager just cares about keeping the count of cached files under a specific count, but doesn't decrease that count when kdevelop is idle.
+		m_backgroundParser->lock();
+		m_backgroundParser->saveMemory();
+		m_backgroundParser->unlock();
+	}
+}
+
 void CppSupportPart::slotSwitchHeader( bool scrollOnly )
 {
 	QString candidate = sourceOrHeaderCandidate();
@@ -1327,6 +1339,7 @@ bool CppSupportPart::parseProject( bool force )
 	kdDebug( 9007 ) << "CppSupportPart::parseProject 5" << endl;
 	QTimer::singleShot( 0, this, SLOT( slotParseFiles() ) );
 
+	m_saveMemoryTimer->stop(); //Do not regularly remove cached files that may still be needed while parsing(the cache anyway be full for the whole parsing-process)
 	return true;
 }
 
@@ -1428,6 +1441,7 @@ void CppSupportPart::slotParseFiles()
 
 			delete _jd;
 			_jd = 0;
+			m_saveMemoryTimer->start( 240000, false );
 		} else {
 			_jd->progressBar->setProgress( _jd->backgroundState ); ///restart
 			_jd->progressBar->setTotalSteps( _jd->backgroundCount );
@@ -1731,7 +1745,8 @@ void CppSupportPart::setupCatalog( )
 	{
 		for ( QStringList::Iterator it = pcsList.begin(); it != pcsList.end(); ++it )
 		{
-			enabledPCSs.push_back( QFileInfo( *it ).baseName() );
+			kdDebug( 9007 ) << "CppSupportPart::setupCatalog()1 " << *it << endl;
+			enabledPCSs.push_back( QFileInfo( *it ).baseName(true) );
 		}
 	}
 	else
@@ -1771,9 +1786,10 @@ void CppSupportPart::setupCatalog( )
 	QStringList::Iterator it = pcsList.begin();
 	while ( it != pcsList.end() )
 	{
+		kdDebug( 9007 ) << "CppSupportPart::setupCatalog()2 " << *it << endl;
 		Catalog * catalog = new Catalog();
 		catalog->open( *it );
-		catalog->setEnabled( enabledPCSs.contains( QFileInfo( *it ).baseName() ) );
+		catalog->setEnabled( enabledPCSs.contains( QFileInfo( *it ).baseName(true) ) );
 		++it;
 
 		for ( QStringList::Iterator idxIt = indexList.begin(); idxIt != indexList.end(); ++idxIt )
@@ -1851,10 +1867,15 @@ QString CppSupportPart::formatTag( const Tag & inputTag )
 void CppSupportPart::codeCompletionConfigStored( )
 {
 	if ( m_projectClosing ) return;
-
+	updateParserConfiguration();
+	/*
 	m_backgroundParser->updateParserConfiguration();
-	KDevDriver* d = dynamic_cast<KDevDriver*>( m_driver );
-	if( d ) d->setup();
+
+	KDevDriver* d = dynamic_cast<KDevDriver*>( m_driver ); //The foreground-parse isn't used anymore, and could be removed
+	if( d ) {
+		d->setup();
+		d->makeMacrosPersistent();
+	}*/
 	partController() ->setActivePart( partController()->activePart() );
 }
 
@@ -2385,14 +2406,17 @@ void CppSupportPart::removeCatalog( const QString & dbName )
 
 	QFileInfo fileInfo( dbName );
 	QDir dir( fileInfo.dir( true ) );
-	QStringList fileList = dir.entryList( fileInfo.baseName() + "*.idx" );
-	for ( QStringList::Iterator it = fileList.begin(); it != fileList.end(); ++it )
+	QStringList indexList = QStringList() << "kind" << "name" << "scope" << "fileName" << "prefix";
+	for(QStringList::Iterator iter = indexList.begin(); iter != indexList.end(); iter++)
 	{
-		QString idxName = fileInfo.dirPath( true ) + "/" + *it;
-	kdDebug( 9007 ) << "=========> remove db index: " << idxName << endl;
-		dir.remove( *it );
+		QStringList fileList = dir.entryList( fileInfo.baseName(true) +"." +(*iter) + ".idx" );
+		for ( QStringList::Iterator it = fileList.begin(); it != fileList.end(); ++it )
+		{
+			QString idxName = fileInfo.dirPath( true ) + "/" + *it;
+		kdDebug( 9007 ) << "=========> remove db index: " << idxName << endl;
+			dir.remove( *it );
+		}
 	}
-
 	dir.remove( fileInfo.fileName() );
 }
 
@@ -2478,9 +2502,10 @@ void CppSupportPart::updateParserConfiguration()
 	m_backgroundParser->updateParserConfiguration();
 
 	QString conf_file_name = specialHeaderName();
-	m_driver->removeAllMacrosInFile( conf_file_name );
 
-	m_driver->parseFile( conf_file_name, true, true );
+	m_driver->removeAllMacrosInFile( conf_file_name );
+	dynamic_cast<KDevDriver*>(m_driver)->setup();
+	m_driver->parseFile( conf_file_name, true, true, true );
 
 	parseProject( true );
 }
