@@ -29,7 +29,7 @@
 #include <qdir.h>
 #include <qprogressbar.h>
 #include <kdebug.h>
-#include <driver.h>
+#include "driver.h"
 
 class Context;
 class CppCodeCompletion;
@@ -222,6 +222,7 @@ private slots:
 	void slotCreateSubclass();
 	void slotCreateAccessMethods();
 	void slotDeleteParserStore();
+    void slotSaveMemory();
 
 	void slotNeedTextHint( int, int, QString& );
 
@@ -339,6 +340,7 @@ private:
 
 	QTimer* m_functionHintTimer;
 	QTimer* m_deleteParserStoreTimer;
+	QTimer* m_saveMemoryTimer;
     
     class ParseEmitWaiting {
     public:
