@@ -258,6 +258,8 @@ void VariableTree::slotContextMenu(KListView *, QListViewItem *item)
         int idCharacter = -2;
         int idBinary = -2;
 
+#define MAYBE_DISABLE(id) if (!var->isAlive()) popup.setItemEnabled(id, false)
+
         VarItem* var;
         if ((var = dynamic_cast<VarItem*>(item))) 
         {
@@ -284,7 +286,8 @@ void VariableTree::slotContextMenu(KListView *, QListViewItem *item)
 
             format.setItemChecked((int)(var->format()), true);
 
-            popup.insertItem(i18n("Format"), &format);
+            int id = popup.insertItem(i18n("Format"), &format);
+            MAYBE_DISABLE(id);
         }
         
 
@@ -294,6 +297,7 @@ void VariableTree::slotContextMenu(KListView *, QListViewItem *item)
         {
             idRemember = popup.insertItem(
                 SmallIcon("pencil"), i18n("Remember Value"));
+            MAYBE_DISABLE(idRemember);
         }
 
         if (dynamic_cast<WatchRoot*>(root)) {
@@ -303,10 +307,12 @@ void VariableTree::slotContextMenu(KListView *, QListViewItem *item)
         } else if (root != recentExpressions_) {
             idWatch = popup.insertItem(
                 i18n("Watch Variable"));
+            MAYBE_DISABLE(idWatch);
         }
         if (root == recentExpressions_) {
             idReevaluate = popup.insertItem( 
                 SmallIcon("reload"), i18n("Reevaluate Expression") );
+            MAYBE_DISABLE(idReevaluate);
             idRemove = popup.insertItem( 
                 SmallIcon("editdelete"), i18n("Remove Expression") );
             popup.setAccel(Qt::Key_Delete, idRemove);
@@ -318,12 +324,15 @@ void VariableTree::slotContextMenu(KListView *, QListViewItem *item)
             popup.setItemEnabled(idToggleWatch, false);
         }
 
-        int	idCopyToClipboard = popup.insertItem( 
+        int     idCopyToClipboard = popup.insertItem( 
             SmallIcon("editcopy"), i18n("Copy Value") );
         popup.setAccel(Qt::CTRL + Qt::Key_C, idCopyToClipboard);
 
         activePopup_ = &popup;
-        if (var)
+        /* This code can be executed when debugger is stopped,
+           and we invoke popup menu on a var under "recent expressions"
+           just to delete it. */
+        if (var && var->isAlive() && !controller()->stateIsOn(s_dbgNotStarted))
             controller_->addCommand(
                 new GDBCommand(
                     QString("-data-evaluate-expression &%1")
@@ -388,6 +397,8 @@ void VariableTree::slotContextMenu(KListView *, QListViewItem *item)
             SmallIcon("editdelete"), i18n("Remove All"));
         int idReevaluate = popup.insertItem(
             SmallIcon("reload"), i18n("Reevaluate All"));
+        if (controller()->stateIsOn(s_dbgNotStarted))
+            popup.setItemEnabled(idReevaluate, false);
         int res = popup.exec(QCursor::pos());
         
         if (res == idRemove)
@@ -606,7 +617,8 @@ public:
     ValueSpecialRepresentationCommand(VarItem* item, const QString& command)
     : CliCommand(command.ascii(),
                  this,
-                 &ValueSpecialRepresentationCommand::handleReply),
+                 &ValueSpecialRepresentationCommand::handleReply,
+                 true),
       item_(item)
     {}
 
@@ -1071,7 +1083,9 @@ VarItem::VarItem(TrimmableItem *parent,
       childrenFetched_(false),
       updateUnconditionally_(false),
       frozen_(frozen),
-      initialCreation_(true)
+      initialCreation_(true),
+      alive_(true),
+      baseClassMember_(false)
 {
     connect(this, SIGNAL(varobjNameChange(const QString&, const QString&)),
             varTree(), 
@@ -1105,15 +1119,18 @@ VarItem::VarItem(TrimmableItem *parent,
 }
 
 VarItem::VarItem(TrimmableItem *parent, const GDBMI::Value& varobj,
-                 format_t format)
+                 format_t format, bool baseClassMember)
 : TrimmableItem (parent),
   highlight_(false),
   oldSpecialRepresentationSet_(false),
   format_(format),
   numChildren_(0),
   childrenFetched_(false),
+  updateUnconditionally_(false),
   frozen_(false),
-  initialCreation_(false)
+  initialCreation_(false),
+  alive_(true),
+  baseClassMember_(baseClassMember)
 { 
     connect(this, SIGNAL(varobjNameChange(const QString&, const QString&)),
             varTree(), 
@@ -1187,7 +1204,7 @@ void VarItem::varobjCreated(const GDBMI::ResultRecord& r)
         varobjName_ = "";
         return;
     }
-    setEnabledRecursively(true);
+    setAliveRecursively(true);
 
     QString oldType = originalValueType_;
     originalValueType_ = r["type"].literal();
@@ -1317,10 +1334,27 @@ void VarItem::valueDone(const GDBMI::ResultRecord& r)
     }
 }
 
-void VarItem::childrenDone(const GDBMI::ResultRecord& r)
+void VarItem::createChildren(const GDBMI::ResultRecord& r, 
+                             bool children_of_fake)
 {
     const GDBMI::Value& children = r["children"];
 
+    /* In order to figure out which variable objects correspond
+       to base class subobject, we first must detect if *this
+       is a structure type. We use present of 'public'/'private'/'protected'
+       fake child as an indicator. */
+    bool structureType = false;
+    if (!children_of_fake && children.size() > 0)
+    {
+        QString exp = children[0]["exp"].literal();
+        bool ok = false;
+        exp.toInt(&ok);
+        if (!ok || exp[0] != '*')
+        {
+            structureType = true;
+        } 
+    }
+                                         
     for (unsigned i = 0; i < children.size(); ++i)
     {
         QString exp = children[i]["exp"].literal();
@@ -1333,10 +1367,14 @@ void VarItem::childrenDone(const GDBMI::ResultRecord& r)
                                         "-var-list-children \"" + 
                                         name + "\"",
                                         this,
-                                        &VarItem::childrenDone));            
+                                        &VarItem::childrenOfFakesDone));
         }
         else
         {
+            /* All children of structures that are not artifical
+               are base subobjects. */
+            bool baseObject = structureType;
+
             VarItem* existing = 0;
             for(QListViewItem* child = firstChild();
                 child; child = child->nextSibling())
@@ -1356,16 +1394,28 @@ void VarItem::childrenDone(const GDBMI::ResultRecord& r)
             }
             else
             {
+                kdDebug(9012) << "Creating new varobj " 
+                              << exp << " " << baseObject << "\n";
                 // Propagate format from parent.
                 VarItem* v = 0;
-                v = new VarItem(this, children[i], format_);
+                v = new VarItem(this, children[i], format_, baseObject);
             }
         }
     }
+}
 
+
+void VarItem::childrenDone(const GDBMI::ResultRecord& r)
+{
+    createChildren(r, false);
     childrenFetched_ = true;
 }
 
+void VarItem::childrenOfFakesDone(const GDBMI::ResultRecord& r)
+{
+    createChildren(r, true);
+}
+
 void VarItem::handleCurrentAddress(const QValueVector<QString>& lines)
 {
     if (lines.count() > 1)
@@ -1431,13 +1481,13 @@ QString VarItem::displayName() const
     }
 }
 
-void VarItem::setEnabledRecursively(bool enable)
+void VarItem::setAliveRecursively(bool enable)
 {
     setEnabled(enable);
     for(QListViewItem* child = firstChild();
         child; child = child->nextSibling())
     {
-        static_cast<VarItem*>(child)->setEnabledRecursively(enable);
+        static_cast<VarItem*>(child)->setAliveRecursively(enable);
     }
 }
 
@@ -1482,7 +1532,13 @@ QString VarItem::gdbExpression() const
     else
     {        
         if (parent)
-            return parent->gdbExpression() + "." + expression_;
+            /* This is varitem corresponds to a base suboject, 
+               the expression should cast parent to the base's
+               type. */
+            if (baseClassMember_)
+                return "((" + expression_ + ")" + parent->gdbExpression() + ")";
+            else
+                return parent->gdbExpression() + "." + expression_;
         else
             return expression_;                
     }
@@ -1652,15 +1708,28 @@ bool VarItem::handleSpecialTypes()
 
         VariableTree* varTree = static_cast<VariableTree*>(listView());
 
-        QString command;
+        varTree->controller()->addCommand(
+            new ResultlessCommand(QString("print $kdev_d=%1.d")
+                                  .arg(gdbExpression()), 
+                                  true /* ignore error */));
+
         if (varTree->controller()->qtVersion() >= 4)
-            command = "print (($len=($data=%1.d).size)?*((char*)&$data.data[0])@($len>100?200:$len*2):\"\")";
+            varTree->controller()->addCommand(
+                new ResultlessCommand(QString("print $kdev_s=$kdev_d.size")
+                               .arg(gdbExpression()), true));
         else
-            command = "print (($len=($data=%1.d).len)?*((char*)&$data.unicode[0])@($len>100?200:$len*2):\"\")";
+            varTree->controller()->addCommand(
+                new ResultlessCommand(QString("print $kdev_s=$kdev_d.len")
+                                      .arg(gdbExpression()), true));
 
+        varTree->controller()->addCommand(
+            new ResultlessCommand(
+                QString("print $kdev_s= ($kdev_s > 0)? ($kdev_s > 100 ? 200 : 2*$kdev_s) : 0")
+                .arg(gdbExpression()), true));
+        
         varTree->controller()->addCommand(
             new ValueSpecialRepresentationCommand(
-                this, command.arg(gdbExpression())));
+                this, "print ($kdev_s>0) ? (*((char*)&$kdev_d.unicode[0])@$kdev_s) : \"\""));
 
         return true;
     }
@@ -1775,12 +1844,22 @@ void VarItem::paintCell(QPainter *p, const QColorGroup &cg,
         p->setFont(KGlobalSettings::fixedFont());
     }
 
-    if (column == ValueCol && highlight_) {
-        QColorGroup hl_cg( cg.foreground(), cg.background(), cg.light(),
-                           cg.dark(), cg.mid(), red, cg.base());
-        QListViewItem::paintCell( p, hl_cg, column, width, align );
-    } else
-        QListViewItem::paintCell( p, cg, column, width, align );
+    if (!alive_)
+    {
+        /* Draw this as disabled. */
+        QListViewItem::paintCell(p, varTree()->QWidget::palette().disabled(), 
+                                 column, width, align);
+    }
+    else
+    {
+        if (column == ValueCol && highlight_) 
+        {
+            QColorGroup hl_cg( cg.foreground(), cg.background(), cg.light(),
+                               cg.dark(), cg.mid(), red, cg.base());
+            QListViewItem::paintCell( p, hl_cg, column, width, align );
+        } else
+            QListViewItem::paintCell( p, cg, column, width, align );
+    }
 }
 
 
@@ -1800,7 +1879,7 @@ void VarItem::unhookFromGdb()
         static_cast<VarItem*>(child)->unhookFromGdb();
     }
 
-    setEnabled(false);
+    alive_ = false;
     childrenFetched_ = false;
 
     emit varobjNameChange(varobjName_, "");
@@ -1837,6 +1916,11 @@ bool VarItem::updateUnconditionally() const
     return updateUnconditionally_;
 }
 
+bool VarItem::isAlive() const
+{
+    return alive_;
+}
+
 
 // **************************************************************************
 // **************************************************************************
