@@ -3,16 +3,16 @@
 #define __kdevdriver_h
 
 #include "cppsupportpart.h"
+#include "driver.h"
 
 #include <kdevproject.h>
 #include <kdeversion.h>
 
-#include <driver.h>
-#include <qprocess.h>
-
 #include <cstdlib>
 #include <unistd.h>
 
+class KProcess;
+
 class KDevDriver: public Driver
 {
 public:
@@ -32,7 +32,7 @@ public:
 
 protected:
 	void setupLexer( Lexer* lexer );
-
+  
 private:
 	CppSupportPart* m_cppSupport;
 };
