@@ -120,7 +120,7 @@ void SimpleType::destroyStore() {
   SafetyCounter s( 30000 );
   while ( !m_typeStore.empty() && s ) {
     TypeStore::iterator it = m_typeStore.begin();
-    SimpleTypeImpl* tp = *it;
+    TypePointer tp = *it;
     m_destroyedStore.insert( tp );
     m_typeStore.erase( it );
     tp->breakReferences();
@@ -196,6 +196,7 @@ SimpleTypeImpl::TypeOfResult SimpleTypeImpl::typeOf( const TypeDesc& name, Membe
         ///Search all bases and append all functions with the same name to it.
         QValueList<LocateResult> bases = getBases();
         for ( QValueList<LocateResult>::iterator it = bases.begin(); it != bases.end(); ++it ) {
+          if( !safetyCounter ) break;
           if ( ( *it ) ->resolved() ) {
             TypeOfResult rt = ( *it ) ->resolved() ->typeOf( name );
             if ( rt->resolved() )
