@@ -4,7 +4,7 @@
 
 #include <stdlib.h>
 
-#include <qlineedit.h>
+#include <klineedit.h>
 #include <qcheckbox.h>
 #include <qbuttongroup.h>
 
