@@ -134,6 +134,8 @@ void PluginController::loadProjectPlugins( const QStringList & ignorePlugins )
 
 void PluginController::loadPlugins( KTrader::OfferList offers, const QStringList & ignorePlugins )
 {
+
+  TopLevel::getInstance()->main()->setFocus();
   for (KTrader::OfferList::ConstIterator it = offers.begin(); it != offers.end(); ++it)
   {
     QString name = (*it)->desktopEntryName();
@@ -231,9 +233,9 @@ QStringList PluginController::argumentsFromService( const KService::Ptr &service
 void PluginController::integratePart(KXMLGUIClient *part)
 {
     if ( ! part ) return;
-
+    Core::setupShourtcutTips(part);
+    
     TopLevel::getInstance()->main()->guiFactory()->addClient(part);
-
     connect( part->actionCollection(), SIGNAL( actionStatusText( const QString & ) ),
         TopLevel::getInstance()->main()->actionCollection(), SIGNAL( actionStatusText( const QString & ) ) );
 }
@@ -246,6 +248,7 @@ void PluginController::integrateAndRememberPart(const QString &name, KDevPlugin
 
 void PluginController::removePart(KXMLGUIClient *part)
 {
+  if (TopLevel::mainWindowValid()) // is 0 when window was already closed
   TopLevel::getInstance()->main()->guiFactory()->removeClient(part);
 }
 
