@@ -31,20 +31,20 @@ Profile::Profile(Profile *parent, const QString &name)
 {
     if (m_parent)
         m_parent->addChildProfile(this);
-    
+
     QString profileConfig = locate("data", "kdevelop/profiles" + dirName() + "/profile.config");
     KConfig config(profileConfig);
-    
+
     config.setGroup("Information");
     m_genericName = config.readEntry("GenericName");
     m_description = config.readEntry("Description");
-    
+
     config.setGroup("Properties");
     m_properties = config.readListEntry("List");
-    
+
     config.setGroup("Enable");
     m_explicitEnable = config.readListEntry("List");
-    
+
     config.setGroup("Disable");
     m_explicitDisable = config.readListEntry("List");
 }
@@ -85,20 +85,20 @@ void Profile::save()
 {
     QString profileConfig = locateLocal("data", "kdevelop/profiles" + dirName() + "/profile.config");
     KConfig config(profileConfig);
-    
+
     config.setGroup("Information");
     config.writeEntry("GenericName", m_genericName);
     config.writeEntry("Description", m_description);
-    
+
     config.setGroup("Properties");
     config.writeEntry("List", m_properties);
-    
+
     config.setGroup("Enable");
     config.writeEntry("List", m_explicitEnable);
-    
+
     config.setGroup("Disable");
     config.writeEntry("List", m_explicitDisable);
-    
+
     config.sync();
 }
 
@@ -129,6 +129,19 @@ void Profile::removeEntry(List type, const QString &value)
     list.remove(value);
 }
 
+void Profile::clearList( List type )
+{
+    switch (type)
+    {
+        case Properties:
+            m_properties.clear();
+        case ExplicitEnable:
+            m_explicitEnable.clear();
+        case ExplicitDisable:
+            m_explicitDisable.clear();
+    }
+}
+
 QStringList &Profile::listByType(List type)
 {
     switch (type) {
@@ -139,13 +152,7 @@ QStringList &Profile::listByType(List type)
         case ExplicitDisable:
             return m_explicitDisable;
     }
-
-    // This is ugly, but at least it returns something (and compiles).
-
-    static QStringList empty;
-    empty.clear();
-
-    return empty;
+//FIXME: What to return here?
 }
 
 bool Profile::hasInEntryList(EntryList &list, QString value)
@@ -178,7 +185,7 @@ KURL::List Profile::resources(const QString &nameFilter)
     {
         QString dir = *it;
         dir = dir + "kdevelop/profiles" + dirName();
-        
+
         QDir d(dir);
         const QFileInfoList *infoList = d.entryInfoList(nameFilter, QDir::Files);
         if (!infoList)
@@ -187,7 +194,7 @@ KURL::List Profile::resources(const QString &nameFilter)
              infoIt != infoList->constEnd(); ++ infoIt)
             resources.append((*infoIt)->absFilePath());
     }
-    
+
     return KURL::List(resources);
 }
 
