@@ -34,12 +34,14 @@
 #include <ktexteditor/document.h>
 #include <kapplication.h>
 #include <kurldrag.h>
+#include <kconfig.h>
 
 #include <ddockwindow.h>
 #include <dtabwidget.h>
 #include <profile.h>
 #include <profileengine.h>
 #include <designer.h>
+#include <kdevproject.h>
 
 #include "api.h"
 #include "core.h"
@@ -103,6 +105,7 @@ void SimpleMainWindow::init()
 
     connect(Core::getInstance(), SIGNAL(coreInitialized()), this, SLOT(slotCoreInitialized()));
     connect(Core::getInstance(), SIGNAL(projectOpened()), this, SLOT(projectOpened()));
+    connect(Core::getInstance(), SIGNAL(projectClosed()), this, SLOT(projectClosed()));
     connect(Core::getInstance(), SIGNAL(contextMenu(QPopupMenu *, const Context *)),
         this, SLOT(contextMenu(QPopupMenu *, const Context *)));
     connect(PartController::getInstance(), SIGNAL(partURLChanged(KParts::ReadOnlyPart *)),
@@ -165,14 +168,19 @@ void SimpleMainWindow::contextMenu(QPopupMenu *popupMenu, const Context *context
             bool isOpen = true;
             for (KURL::List::const_iterator it = m_splitURLs.begin(); it != m_splitURLs.end(); ++it)
             {
-                if (!PartController::getInstance()->openURLs().contains(*it))
+                if (!PartController::getInstance()->openURLs().contains(*it) && (*it).isValid())
                 {
                     isOpen = false;
                     break;
                 }
             }
-            if (isOpen && PartController::getInstance()->openURLs().count() == 1)
+
+            if ( (isOpen && PartController::getInstance()->openURLs().count() == 1) ||
+                 (m_splitURLs.count() == 1 && !(*m_splitURLs.begin()).isValid() ) )
+            {
                 return;
+            }
+
             popupMenu->insertSeparator();
             if (isOpen)
             {
@@ -203,22 +211,77 @@ void SimpleMainWindow::embedPartView(QWidget *view, const QString &title, const
 
 void SimpleMainWindow::embedSelectView(QWidget *view, const QString &title, const QString &/*toolTip*/)
 {
-    toolWindow(DDockWindow::Left)->addWidget(title, view);
-    m_docks[view] = DDockWindow::Left;
+    embedView( DDockWindow::Left, view, title );
 }
 
 void SimpleMainWindow::embedOutputView(QWidget *view, const QString &title, const QString &/*toolTip*/)
 {
-    toolWindow(DDockWindow::Bottom)->addWidget(title, view);
-    m_docks[view] = DDockWindow::Bottom;
+    embedView( DDockWindow::Bottom, view, title );
 }
 
 void SimpleMainWindow::embedSelectViewRight(QWidget *view, const QString &title, const QString &/*toolTip*/)
 {
-    toolWindow(DDockWindow::Right)->addWidget(title, view);
-    m_docks[view] = DDockWindow::Right;
+    embedView( DDockWindow::Right, view, title );
 }
 
+void SimpleMainWindow::embedView( DDockWindow::Position pos, QWidget * view, const QString & title )
+{
+    if ( !hasDockWidget( view ) )
+    {
+        DDockWindow::Position position = recallToolViewPosition( view->name(), pos );
+        addDockWidget(position, view, title);
+    }
+}
+
+DDockWindow::Position SimpleMainWindow::recallToolViewPosition( const QString & name, DDockWindow::Position defaultPos )
+{
+    KConfig * config = kapp->config();
+    config->setGroup( "DToolDockPosition" );
+
+    QString position = config->readEntry( name );
+
+    if ( name == "unknown" )
+    {
+        kdDebug() << name << endl;
+    }
+
+    if ( position == "DockLeft" ) return DDockWindow::Left;
+    if ( position == "DockRight" ) return DDockWindow::Right;
+    if ( position == "DockBottom" ) return DDockWindow::Bottom;
+
+    return defaultPos;
+}
+
+void SimpleMainWindow::rememberToolViewPosition( const QString & name, DDockWindow::Position pos )
+{
+    KConfig * config = kapp->config();
+    config->setGroup( "DToolDockPosition" );
+
+    if ( name == "unknown" )
+    {
+        kdDebug() << name << endl;
+    }
+
+    QString position = "unknown";
+
+    switch( pos )
+    {
+        case DDockWindow::Left:
+            position = "DockLeft";
+            break;
+        case DDockWindow::Right:
+            position = "DockRight";
+            break;
+        case DDockWindow::Bottom:
+            position = "DockBottom";
+            break;
+        default: ;
+    }
+
+    config->writeEntry( name, position );
+}
+
+
 void SimpleMainWindow::removeView(QWidget *view)
 {
     if (!view)
@@ -226,8 +289,11 @@ void SimpleMainWindow::removeView(QWidget *view)
 
     //try to remove it from all parts of main window
     //@fixme This method needs to be divided in two - one for docks and one for part views
-    if (m_docks.contains(view))
-        toolWindow(m_docks[view])->removeWidget(view);
+    if (hasDockWidget(view))
+    {
+        rememberToolViewPosition( view->name(), dockWidgetPosition(view) );
+        removeDockWidget(view);
+    }
     else
         removeWidget(view);
 }
@@ -235,8 +301,8 @@ void SimpleMainWindow::removeView(QWidget *view)
 void SimpleMainWindow::setViewAvailable(QWidget *pView, bool bEnabled)
 {
     DDockWindow *dock;
-    if (m_docks.contains(pView))
-        dock = toolWindow(m_docks[pView]);
+    if (hasDockWidget(pView))
+        dock = toolWindow(dockWidgetPosition(pView));
     else
         return;
 
@@ -258,18 +324,22 @@ void SimpleMainWindow::raiseView(QWidget *view)
         view = (QWidget*)view->parent();
     }
 
-    if (m_docks.contains(view))
+    if (hasDockWidget(view))
     {
-        DDockWindow *dock = toolWindow(m_docks[view]);
+        DDockWindow *dock = toolWindow(dockWidgetPosition(view));
         dock->raiseWidget(view);
     }
     else if (m_widgets.contains(view) && m_widgetTabs.contains(view))
         m_widgetTabs[view]->showPage(view);
 }
 
-void SimpleMainWindow::lowerView(QWidget */*view*/)
+void SimpleMainWindow::lowerView(QWidget * view)
 {
-    //nothing to do
+    if (!hasDockWidget(view))
+        return;
+
+    DDockWindow *dock = toolWindow(dockWidgetPosition(view));
+    dock->lowerWidget(view);
 }
 
 void SimpleMainWindow::loadSettings()
@@ -289,17 +359,24 @@ void SimpleMainWindow::saveSettings( )
     ProjectManager::getInstance()->saveSettings();
     saveMainWindowSettings(config, "SimpleMainWindow");
 
+    QMap<QWidget*, DDockWindow::Position>::iterator it = m_docks.begin();
+    while ( it != m_docks.end() )
+    {
+        rememberToolViewPosition( it.key()->name(), it.data() );
+        ++it;
+    }
+
     DMainWindow::saveSettings();
 }
 
 void SimpleMainWindow::setCurrentDocumentCaption( const QString &caption )
 {
-	if( !PartController::getInstance()->activePart() ) return;
-	
-	if (QWidget *widget = EditorProxy::getInstance()->topWidgetForPart(PartController::getInstance()->activePart()))
-	{
-		widget->setCaption(caption);
-	}
+    if( !PartController::getInstance()->activePart() ) return;
+
+    if (QWidget *widget = EditorProxy::getInstance()->topWidgetForPart(PartController::getInstance()->activePart()))
+    {
+        widget->setCaption(caption);
+    }
 }
 
 KMainWindow *SimpleMainWindow::main()
@@ -322,10 +399,10 @@ void SimpleMainWindow::createActions()
     m_raiseEditor->setToolTip(i18n("Raise editor"));
     m_raiseEditor->setWhatsThis(i18n("<b>Raise editor</b><p>Focuses the editor."));
 
-    m_lowerAllDocks = new KAction(i18n("Lower All Docks"), CTRL+SHIFT+Key_C, 
+    m_lowerAllDocks = new KAction(i18n("Lower All Docks"), CTRL+SHIFT+Key_C,
         this, SLOT(lowerAllDocks()), actionCollection(), "lower_all_docks");
 
-    new KAction(i18n("Switch to next TabWidget"), 0, this, 
+    new KAction(i18n("Switch to next TabWidget"), 0, this,
         SLOT(switchToNextTabWidget()), actionCollection(), "switch_to_next_tabwidget" );
 
     m_splitHor = new KAction(i18n("Split &Horizontal"), CTRL+SHIFT+Key_T,
@@ -864,4 +941,31 @@ void SimpleMainWindow::switchToNextTabWidget()
     }
 }
 
+void SimpleMainWindow::setCaption(const QString &caption)
+{
+    KDevProject *project = API::getInstance()->project();
+    if (project)
+    {
+        QString projectname = project->projectName();
+
+        QString suffix(".kdevelop");
+        if (projectname.endsWith(suffix))
+            projectname.truncate(projectname.length() - suffix.length());
+
+        if (!caption.isEmpty())
+            DMainWindow::setCaption(projectname + " - " + caption);
+        else
+            DMainWindow::setCaption(projectname);
+    }
+    else
+        DMainWindow::setCaption(caption);
+}
+
+void SimpleMainWindow::projectClosed()
+{
+    DMainWindow::setCaption(QString::null);
+}
+
 #include "simplemainwindow.moc"
+
+// kate: space-indent on; indent-width 4; tab-width 4; replace-tabs on
